@@ -21,11 +21,8 @@
 #include "ConfigException.hh"
 #include "FileException.hh"
 #include "EnumSetting.hh"
-#include "XMLLoader.hh"
-#include "XMLElement.hh"
 #include "XMLException.hh"
 #include "StringOp.hh"
-#include "utf8_checked.hh"
 #include "xrange.hh"
 #include "GLUtil.hh"
 #include "Reactor.hh"
@@ -42,25 +39,19 @@
 
 #include <cassert>
 #include <iostream>
-#include <cstdio>
 
 using std::cout;
 using std::endl;
-using std::deque;
 using std::string;
 using std::vector;
 
-#ifdef _WIN32
-using namespace utf8;
-#endif
-
 namespace openmsx {
 
 class HelpOption : public CLIOption
 {
 public:
 	explicit HelpOption(CommandLineParser& parser);
-	virtual void parseOption(const string& option, deque<string>& cmdLine);
+	virtual void parseOption(const string& option, array_ref<string>& cmdLine);
 	virtual string_ref optionHelp() const;
 private:
 	CommandLineParser& parser;
@@ -70,7 +61,7 @@ class VersionOption : public CLIOption
 {
 public:
 	explicit VersionOption(CommandLineParser& parser);
-	virtual void parseOption(const string& option, deque<string>& cmdLine);
+	virtual void parseOption(const string& option, array_ref<string>& cmdLine);
 	virtual string_ref optionHelp() const;
 private:
 	CommandLineParser& parser;
@@ -80,7 +71,7 @@ class ControlOption : public CLIOption
 {
 public:
 	explicit ControlOption(CommandLineParser& parser);
-	virtual void parseOption(const string& option, deque<string>& cmdLine);
+	virtual void parseOption(const string& option, array_ref<string>& cmdLine);
 	virtual string_ref optionHelp() const;
 private:
 	CommandLineParser& parser;
@@ -90,10 +81,10 @@ class ScriptOption : public CLIOption, public CLIFileType
 {
 public:
 	const CommandLineParser::Scripts& getScripts() const;
-	virtual void parseOption(const string& option, deque<string>& cmdLine);
+	virtual void parseOption(const string& option, array_ref<string>& cmdLine);
 	virtual string_ref optionHelp() const;
 	virtual void parseFileType(const std::string& filename,
-                                   std::deque<std::string>& cmdLine);
+                                   array_ref<std::string>& cmdLine);
 	virtual string_ref fileTypeHelp() const;
 
 private:
@@ -104,7 +95,7 @@ class MachineOption : public CLIOption
 {
 public:
 	explicit MachineOption(CommandLineParser& parser);
-	virtual void parseOption(const string& option, deque<string>& cmdLine);
+	virtual void parseOption(const string& option, array_ref<string>& cmdLine);
 	virtual string_ref optionHelp() const;
 private:
 	CommandLineParser& parser;
@@ -114,7 +105,7 @@ class SettingOption : public CLIOption
 {
 public:
 	explicit SettingOption(CommandLineParser& parser);
-	virtual void parseOption(const string& option, deque<string>& cmdLine);
+	virtual void parseOption(const string& option, array_ref<string>& cmdLine);
 	virtual string_ref optionHelp() const;
 private:
 	CommandLineParser& parser;
@@ -122,7 +113,7 @@ private:
 
 class NoPBOOption : public CLIOption {
 public:
-	virtual void parseOption(const string& option, deque<string>& cmdLine);
+	virtual void parseOption(const string& option, array_ref<string>& cmdLine);
 	virtual string_ref optionHelp() const;
 };
 
@@ -130,7 +121,7 @@ class TestConfigOption : public CLIOption
 {
 public:
 	explicit TestConfigOption(CommandLineParser& parser);
-	virtual void parseOption(const string& option, deque<string>& cmdLine);
+	virtual void parseOption(const string& option, array_ref<string>& cmdLine);
 	virtual string_ref optionHelp() const;
 private:
 	CommandLineParser& parser;
@@ -140,7 +131,7 @@ class BashOption : public CLIOption
 {
 public:
 	explicit BashOption(CommandLineParser& parser);
-	virtual void parseOption(const string& option, deque<string>& cmdLine);
+	virtual void parseOption(const string& option, array_ref<string>& cmdLine);
 	virtual string_ref optionHelp() const;
 private:
 	CommandLineParser& parser;
@@ -209,23 +200,19 @@ CommandLineParser::~CommandLineParser()
 void CommandLineParser::registerOption(
 	const char* str, CLIOption& cliOption, ParsePhase phase, unsigned length)
 {
-	OptionData temp;
-	temp.option = &cliOption;
-	temp.phase = phase;
-	temp.length = length;
-	options.push_back(std::make_pair(str, temp));
+	options.emplace_back(str, OptionData{&cliOption, phase, length});
 }
 
 void CommandLineParser::registerFileType(
 	string_ref extensions, CLIFileType& cliFileType)
 {
 	for (auto& ext: StringOp::split(extensions, ',')) {
-		fileTypes.push_back(std::make_pair(ext, &cliFileType));
+		fileTypes.emplace_back(ext, &cliFileType);
 	}
 }
 
 bool CommandLineParser::parseOption(
-	const string& arg, deque<string>& cmdLine, ParsePhase phase)
+	const string& arg, array_ref<string>& cmdLine, ParsePhase phase)
 {
 	auto it = lower_bound(options.begin(), options.end(), arg,
 	                      CmpOptions());
@@ -243,7 +230,7 @@ bool CommandLineParser::parseOption(
 	return false; // unknown
 }
 
-bool CommandLineParser::parseFileName(const string& arg, deque<string>& cmdLine)
+bool CommandLineParser::parseFileName(const string& arg, array_ref<string>& cmdLine)
 {
 	// First try the fileName as we get it from the commandline. This may
 	// be more interesting than the original fileName of a (g)zipped file:
@@ -263,7 +250,7 @@ bool CommandLineParser::parseFileName(const string& arg, deque<string>& cmdLine)
 	return processed;
 }
 
-bool CommandLineParser::parseFileNameInner(const string& name, const string& originalPath, deque<string>& cmdLine)
+bool CommandLineParser::parseFileNameInner(const string& name, const string& originalPath, array_ref<string>& cmdLine)
 {
 	string_ref extension = FileOperations::getExtension(name);
 	if (extension.empty()) {
@@ -290,11 +277,12 @@ void CommandLineParser::parse(int argc, char** argv)
 {
 	parseStatus = RUN;
 
-	deque<string> cmdLine;
-	deque<string> backupCmdLine;
+	vector<string> cmdLineBuf;
 	for (auto i : xrange(1, argc)) {
-		cmdLine.push_back(FileOperations::getConventionalPath(argv[i]));
+		cmdLineBuf.push_back(FileOperations::getConventionalPath(argv[i]));
 	}
+	array_ref<string> cmdLine(cmdLineBuf);
+	vector<string> backupCmdLine;
 
 	for (ParsePhase phase = PHASE_BEFORE_INIT;
 	     (phase <= PHASE_LAST) && (parseStatus != EXIT);
@@ -388,8 +376,9 @@ void CommandLineParser::parse(int argc, char** argv)
 					}
 				}
 			}
-			cmdLine = backupCmdLine;
+			std::swap(backupCmdLine, cmdLineBuf);
 			backupCmdLine.clear();
+			cmdLine = cmdLineBuf;
 			break;
 		}
 	}
@@ -436,7 +425,7 @@ ControlOption::ControlOption(CommandLineParser& parser_)
 {
 }
 
-void ControlOption::parseOption(const string& option, deque<string>& cmdLine)
+void ControlOption::parseOption(const string& option, array_ref<string>& cmdLine)
 {
 	const auto& fullType = getArgument(option, cmdLine);
 	string_ref type, arguments;
@@ -483,7 +472,7 @@ const CommandLineParser::Scripts& ScriptOption::getScripts() const
 	return scripts;
 }
 
-void ScriptOption::parseOption(const string& option, deque<string>& cmdLine)
+void ScriptOption::parseOption(const string& option, array_ref<string>& cmdLine)
 {
 	parseFileType(getArgument(option, cmdLine), cmdLine);
 }
@@ -494,7 +483,7 @@ string_ref ScriptOption::optionHelp() const
 }
 
 void ScriptOption::parseFileType(const string& filename,
-                                   deque<std::string>& /*cmdLine*/)
+                                 array_ref<std::string>& /*cmdLine*/)
 {
 	scripts.push_back(filename);
 }
@@ -573,7 +562,7 @@ HelpOption::HelpOption(CommandLineParser& parser_)
 }
 
 void HelpOption::parseOption(const string& /*option*/,
-                             deque<string>& /*cmdLine*/)
+                             array_ref<string>& /*cmdLine*/)
 {
 	const auto& fullVersion = Version::full();
 	cout << fullVersion << endl;
@@ -619,7 +608,7 @@ VersionOption::VersionOption(CommandLineParser& parser_)
 }
 
 void VersionOption::parseOption(const string& /*option*/,
-                                deque<string>& /*cmdLine*/)
+                                array_ref<string>& /*cmdLine*/)
 {
 	cout << Version::full() << endl;
 	cout << "flavour: " << BUILD_FLAVOUR << endl;
@@ -640,7 +629,7 @@ MachineOption::MachineOption(CommandLineParser& parser_)
 {
 }
 
-void MachineOption::parseOption(const string& option, deque<string>& cmdLine)
+void MachineOption::parseOption(const string& option, array_ref<string>& cmdLine)
 {
 	if (parser.haveConfig) {
 		throw FatalError("Only one machine option allowed");
@@ -665,7 +654,7 @@ SettingOption::SettingOption(CommandLineParser& parser_)
 {
 }
 
-void SettingOption::parseOption(const string& option, deque<string>& cmdLine)
+void SettingOption::parseOption(const string& option, array_ref<string>& cmdLine)
 {
 	if (parser.haveSettings) {
 		throw FatalError("Only one setting option allowed");
@@ -691,7 +680,7 @@ string_ref SettingOption::optionHelp() const
 // class NoPBOOption
 
 void NoPBOOption::parseOption(const string& /*option*/,
-                              deque<string>& /*cmdLine*/)
+                              array_ref<string>& /*cmdLine*/)
 {
 	#if COMPONENT_GL
 	cout << "Disabling PBO" << endl;
@@ -713,7 +702,7 @@ TestConfigOption::TestConfigOption(CommandLineParser& parser_)
 }
 
 void TestConfigOption::parseOption(const string& /*option*/,
-                                   deque<string>& /*cmdLine*/)
+                                   array_ref<string>& /*cmdLine*/)
 {
 	parser.parseStatus = CommandLineParser::TEST;
 }
@@ -731,7 +720,7 @@ BashOption::BashOption(CommandLineParser& parser_)
 }
 
 void BashOption::parseOption(const string& /*option*/,
-                             deque<string>& cmdLine)
+                             array_ref<string>& cmdLine)
 {
 	string last = cmdLine.empty() ? "" : cmdLine.front();
 	cmdLine.clear(); // eat all remaining parameters
@@ -740,7 +729,7 @@ void BashOption::parseOption(const string& /*option*/,
 		for (auto& s : Reactor::getHwConfigs("machines")) {
 			cout << s << '\n';
 		}
-	} else if (last == "-ext") {
+	} else if (StringOp::startsWith(last, "-ext")) {
 		for (auto& s : Reactor::getHwConfigs("extensions")) {
 			cout << s << '\n';
 		}
