@@ -200,7 +200,7 @@ void MSXDevice::registerSlots()
 				getName() + " should be in range "
 				"[0x0000,0x10000).");
 		}
-		tmpMemRegions.push_back(std::make_pair(base, size));
+		tmpMemRegions.emplace_back(base, size);
 	}
 	if (tmpMemRegions.empty()) {
 		return;
@@ -259,6 +259,7 @@ void MSXDevice::registerSlots()
 	} else {
 		// numerical specified slot (0, 1, 2, 3)
 	}
+	assert((0 <= ps) && (ps <= 3));
 
 	if (!getCPUInterface().isExpanded(ps)) {
 		ss = -1;
