@@ -86,8 +86,7 @@ private:
 static XMLElement createXML()
 {
 	XMLElement xml("cassetteplayer");
-	xml.addChild(XMLElement("sound"))
-	        .addChild(XMLElement("volume", "5000"));
+	xml.addChild("sound").addChild("volume", "5000");
 	return xml;
 }
 
@@ -320,6 +319,7 @@ void CassettePlayer::setState(State newState, const Filename& newImage,
 
 void CassettePlayer::updateLoadingState(EmuTime::param time)
 {
+	assert(prevSyncTime == time); // sync() must be called
 	// TODO also set loadingIndicator for RECORD?
 	// note: we don't use isRolling()
 	loadingIndicator->update(motor && (getState() == PLAY));
@@ -476,6 +476,7 @@ void CassettePlayer::updateTapePosition(
 	if (!isRolling()) return;
 
 	tapePos += duration;
+	assert(tapePos <= playImage->getEndTime());
 
 	// synchronize audio with actual tape position
 	if ((getState() == PLAY) && !syncScheduled) {
@@ -613,6 +614,8 @@ void CassettePlayer::executeUntil(EmuTime::param time, int userData)
 	switch (userData) {
 	case END_OF_TAPE:
 		// tape ended
+		sync(time);
+		assert(tapePos == playImage->getEndTime());
 		motherBoard.getMSXCliComm().printWarning(
 			"Tape end reached... stopping. "
 			"You may need to insert another tape image "
@@ -949,9 +952,10 @@ void CassettePlayer::serialize(Archive& ar, unsigned version)
 	ar.serialize("motorControl", motorControl);
 
 	if (ar.isLoader()) {
+		auto time = getCurrentTime();
 		if (playImage && (tapePos > playImage->getEndTime())) {
 			tapePos = playImage->getEndTime();
-			motherBoard.getMSXCliComm().printWarning("Tape position  "
+			motherBoard.getMSXCliComm().printWarning("Tape position "
 				"beyond tape end! Setting tape position to end. "
 				"This can happen if you load a replay from an "
 				"older openMSX version with a different CAS-to-WAV "
@@ -964,14 +968,15 @@ void CassettePlayer::serialize(Archive& ar, unsigned version)
 				"Restoring a state where the MSX was saving to "
 				"tape is not yet supported. Emulation will "
 				"continue without actually saving.");
-			setState(STOP, getImageName(), getCurrentTime());
+			setState(STOP, getImageName(), time);
 		}
 		if (!playImage && (state == PLAY)) {
 			// This should only happen for manually edited
 			// savestates, though we shouldn't crash on it.
-			setState(STOP, getImageName(), getCurrentTime());
+			setState(STOP, getImageName(), time);
 		}
-		updateLoadingState(getCurrentTime());
+		sync(time);
+		updateLoadingState(time);
 	}
 }
 INSTANTIATE_SERIALIZE_METHODS(CassettePlayer);
