@@ -1,5 +1,3 @@
-// $Id: Command.cc 12805 2012-08-13 19:26:18Z m9710797 $
-
 #include "Command.hh"
 #include "CommandController.hh"
 #include "GlobalCommandController.hh"
@@ -42,7 +40,7 @@ CommandController& CommandCompleter::getCommandController() const
 
 GlobalCommandController& CommandCompleter::getGlobalCommandController() const
 {
-	if (GlobalCommandController* globalCommandController =
+	if (auto globalCommandController =
 	    dynamic_cast<GlobalCommandController*>(&commandController)) {
 		return *globalCommandController;
 	} else {
@@ -79,14 +77,12 @@ Command::~Command()
 	}
 }
 
-void Command::execute(const vector<TclObject>& tokens,
-                      TclObject& result)
+void Command::execute(const vector<TclObject>& tokens, TclObject& result)
 {
 	vector<string> strings;
 	strings.reserve(tokens.size());
-	for (vector<TclObject>::const_iterator it = tokens.begin();
-	     it != tokens.end(); ++it) {
-		strings.push_back(it->getString().str());
+	for (auto& t : tokens) {
+		strings.push_back(t.getString().str());
 	}
 	result.setString(execute(strings));
 }
