@@ -1,16 +1,13 @@
-// $Id: TTFFont.cc 12585 2012-06-05 20:26:17Z m9710797 $
-
 #include "TTFFont.hh"
 #include "LocalFileReference.hh"
 #include "MSXException.hh"
 #include "StringOp.hh"
-#include "shared_ptr.hh"
-#include "unreachable.hh"
+#include "memory.hh"
+#include "xrange.hh"
 #include <SDL_ttf.h>
 #include <map>
 #include <algorithm>
 #include <vector>
-#include <iostream>
 #include <cassert>
 
 using std::string;
@@ -54,7 +51,11 @@ private:
 	// of step 3 and 4. Though this has the disadvantage that if openMSX
 	// crashes between step 3 and 4 the temp file is still left behind.
 	struct FontInfo {
-		shared_ptr<LocalFileReference> file; // TODO use c++11 unique_ptr
+		FontInfo() {}
+		FontInfo(FontInfo&& rhs)
+			: file(std::move(rhs.file)), font(std::move(rhs.font))
+			, count(std::move(rhs.count)) {}
+		std::unique_ptr<LocalFileReference> file;
 		TTF_Font* font;
 		int count;
 	};
@@ -104,8 +105,8 @@ TTFFontPool& TTFFontPool::instance()
 
 TTF_Font* TTFFontPool::get(const string& filename, int ptSize)
 {
-	Pool::key_type key = make_pair(filename, ptSize);
-	Pool::iterator it = pool.find(key);
+	auto key = make_pair(filename, ptSize);
+	auto it = pool.find(key);
 	if (it != pool.end()) {
 		++(it->second.count);
 		return it->second.font;
@@ -113,29 +114,27 @@ TTF_Font* TTFFontPool::get(const string& filename, int ptSize)
 
 	SDLTTF::instance(); // init library
 	FontInfo info;
-	info.file.reset(new LocalFileReference(filename));
+	info.file = make_unique<LocalFileReference>(filename);
 	info.font = TTF_OpenFont(info.file->getFilename().c_str(), ptSize);
 	if (!info.font) {
 		throw MSXException(TTF_GetError());
 	}
 	info.count = 1;
-	pool.insert(std::make_pair(key, info));
-	return info.font;
+	auto result = info.font;
+	pool.insert(std::make_pair(key, std::move(info)));
+	return result;
 }
 
 void TTFFontPool::release(TTF_Font* font)
 {
-	for (Pool::iterator it = pool.begin(); it != pool.end(); ++it) {
-		if (it->second.font == font) {
-			--(it->second.count);
-			if (it->second.count == 0) {
-				TTF_CloseFont(it->second.font);
-				pool.erase(it);
-			}
-			return;
-		}
+	auto it = find_if(pool.begin(), pool.end(),
+		[&](Pool::value_type& v) { return v.second.font == font; });
+	assert(it != pool.end());
+	--(it->second.count);
+	if (it->second.count == 0) {
+		TTF_CloseFont(it->second.font);
+		pool.erase(it);
 	}
-	UNREACHABLE;
 }
 
 
@@ -148,6 +147,7 @@ TTFFont::TTFFont(const std::string& filename, int ptSize)
 
 TTFFont::~TTFFont()
 {
+	if (!font) return;
 	TTFFontPool::instance().release(static_cast<TTF_Font*>(font));
 }
 
@@ -157,11 +157,10 @@ SDLSurfacePtr TTFFont::render(std::string text, byte r, byte g, byte b) const
 
 	// Optimization: remove trailing empty lines
 	StringOp::trimRight(text, " \n");
-	if (text.empty()) return SDLSurfacePtr(NULL);
+	if (text.empty()) return SDLSurfacePtr(nullptr);
 
 	// Split on newlines
-	std::vector<string> lines;
-	StringOp::split(text, "\n", lines);
+	auto lines = StringOp::split(text, '\n');
 	assert(!lines.empty());
 
 	if (lines.size() == 1) {
@@ -171,7 +170,7 @@ SDLSurfacePtr TTFFont::render(std::string text, byte r, byte g, byte b) const
 		SDLSurfacePtr surface(
 			TTF_RenderUTF8_Blended(static_cast<TTF_Font*>(font),
 			                       text.c_str(), color));
-		if (!surface.get()) {
+		if (!surface) {
 			throw MSXException(TTF_GetError());
 		}
 		return surface;
@@ -180,9 +179,9 @@ SDLSurfacePtr TTFFont::render(std::string text, byte r, byte g, byte b) const
 	// Determine maximum width and lineHeight
 	unsigned width = 0;
 	unsigned lineHeight = 0; // initialize to avoid warning
-	for (vector<string>::const_iterator it = lines.begin(); it != lines.end(); ++it) {
+	for (auto& s : lines) {
 		unsigned w;
-		getSize(*it, w, lineHeight);
+		getSize(s.str(), w, lineHeight);
 		width = std::max(width, w);
 	}
 	// There might be extra space between two successive lines
@@ -195,34 +194,33 @@ SDLSurfacePtr TTFFont::render(std::string text, byte r, byte g, byte b) const
 	// Create destination surface (initial surface is fully transparent)
 	SDLSurfacePtr destination(SDL_CreateRGBSurface(SDL_SWSURFACE, width, height,
 			32, 0x00FF0000, 0x0000FF00, 0x000000FF, 0xFF000000));
-	if (!destination.get()) {
+	if (!destination) {
 		throw MSXException("Couldn't allocate surface for multiline text.");
 	}
 
 	// Actually render the text:
-	for (unsigned i = 0; i < lines.size(); ++i) {
+	for (auto i : xrange(lines.size())) {
 		// Render single line
 		if (lines[i].empty()) {
 			// SDL_TTF gives an error on empty lines, but we can
 			// simply skip such lines
 			continue;
 		}
-		SDLSurfacePtr line(TTF_RenderUTF8_Blended(static_cast<TTF_Font*>(font),
-		                                          lines[i].c_str(), color));
-		if (!line.get()) {
+		SDLSurfacePtr line(TTF_RenderUTF8_Blended(
+			static_cast<TTF_Font*>(font),
+			lines[i].str().c_str(), color));
+		if (!line) {
 			throw MSXException(TTF_GetError());
 		}
 
 		// Copy line to destination surface
 		SDL_Rect rect;
 		rect.x = 0;
-		rect.y = i * lineSkip;
+		rect.y = Sint16(i * lineSkip);
 		SDL_SetAlpha(line.get(), 0, 0); // no blending during copy
-		SDL_BlitSurface(line.get(), NULL, destination.get(), &rect);
+		SDL_BlitSurface(line.get(), nullptr, destination.get(), &rect);
 	}
 	return destination;
-
-	// TODO for GP2X copy to a HW_Surface?
 }
 
 unsigned TTFFont::getHeight() const
@@ -230,12 +228,17 @@ unsigned TTFFont::getHeight() const
 	return TTF_FontLineSkip(static_cast<TTF_Font*>(font));
 }
 
+bool TTFFont::isFixedWidth() const
+{
+	return TTF_FontFaceIsFixedWidth(static_cast<TTF_Font*>(font)) != 0;
+}
+
 unsigned TTFFont::getWidth() const
 {
 	int advance;
 	if (TTF_GlyphMetrics(static_cast<TTF_Font*>(font), Uint16('M'),
-	                     NULL /*minx*/, NULL /*maxx*/,
-	                     NULL /*miny*/, NULL /*maxy*/,
+	                     nullptr /*minx*/, nullptr /*maxx*/,
+	                     nullptr /*miny*/, nullptr /*maxy*/,
 	                     &advance)) {
 		// error?
 		return 10; //fallback-width
