@@ -34,9 +34,9 @@ namespace openmsx {
 class CliCommandEvent : public Event
 {
 public:
-	CliCommandEvent(const string& command_, const CliConnection* id_)
+	CliCommandEvent(string command_, const CliConnection* id_)
 		: Event(OPENMSX_CLICOMMAND_EVENT)
-		, command(command_), id(id_)
+		, command(std::move(command_)), id(id_)
 	{
 	}
 	const string& getCommand() const
@@ -83,8 +83,8 @@ CliConnection::CliConnection(CommandController& commandController_,
 	parser_context = xmlCreatePushParserCtxt(
 		&sax_handler, &user_data, nullptr, 0, nullptr);
 
-	for (int i = 0; i < CliComm::NUM_UPDATES; ++i) {
-		updateEnabled[i] = false;
+	for (auto& en : updateEnabled) {
+		en = false;
 	}
 
 	eventDistributor.registerEventListener(OPENMSX_CLICOMMAND_EVENT, *this);
@@ -259,7 +259,6 @@ StdioConnection::StdioConnection(CommandController& commandController,
 	, ok(true)
 {
 	startOutput();
-	start();
 }
 
 StdioConnection::~StdioConnection()
@@ -325,7 +324,6 @@ PipeConnection::PipeConnection(CommandController& commandController,
 	}
 
 	startOutput();
-	start();
 }
 
 PipeConnection::~PipeConnection()
@@ -414,7 +412,6 @@ SocketConnection::SocketConnection(CommandController& commandController,
 	: CliConnection(commandController, eventDistributor)
 	, sem(1), sd(sd_), established(false)
 {
-	start();
 }
 
 SocketConnection::~SocketConnection()
