@@ -1,13 +1,13 @@
-// $Id: InputEventFactory.cc 12626 2012-06-14 20:14:17Z m9710797 $
-
 #include "InputEventFactory.hh"
 #include "InputEvents.hh"
 #include "CommandException.hh"
 #include "StringOp.hh"
 #include "Interpreter.hh"
+#include "openmsx.hh"
 
 using std::string;
 using std::vector;
+using std::make_shared;
 
 namespace openmsx {
 
@@ -20,9 +20,9 @@ static EventPtr parseKeyEvent(const string& str, const int unicode)
 		throw CommandException("Invalid keycode: " + str);
 	}
 	if (keyCode & Keys::KD_RELEASE) {
-		return EventPtr(new KeyUpEvent(keyCode, unicode));
+		return make_shared<KeyUpEvent  >(keyCode, unicode);
 	} else {
-		return EventPtr(new KeyDownEvent(keyCode, unicode));
+		return make_shared<KeyDownEvent>(keyCode, unicode);
 	}
 }
 
@@ -58,27 +58,78 @@ static EventPtr parseMouseEvent(
 		throw CommandException("Invalid mouse event: " + str);
 	}
 	if (components[1] == "motion") {
-		if (components.size() != 4) {
+		if (components.size() == 2) {
+			return make_shared<MouseMotionGroupEvent>();
+		}
+		if ((components.size() != 4) && (components.size() != 6)) {
 			throw CommandException("Invalid mouse motion event: " + str);
 		}
-		return EventPtr(new MouseMotionEvent(
+		int absX, absY;
+		if (components.size() == 6) {
+			absX = StringOp::stringToInt(components[4]),
+			absY = StringOp::stringToInt(components[5]);
+		} else {
+			// for bw-compat also allow events without absX,absY
+			absX = absY = 0;
+		}
+		return make_shared<MouseMotionEvent>(
 			StringOp::stringToInt(components[2]),
-			StringOp::stringToInt(components[3])));
+			StringOp::stringToInt(components[3]),
+			absX, absY);
 	} else if (StringOp::startsWith(components[1], "button")) {
 		if (components.size() != 3) {
 			throw CommandException("Invalid mouse button event: " + str);
 		}
 		unsigned button = stoi(string_ref(components[1]).substr(6));
 		if (upDown(components[2])) {
-			return EventPtr(new MouseButtonUpEvent(button));
+			return make_shared<MouseButtonUpEvent>  (button);
 		} else {
-			return EventPtr(new MouseButtonDownEvent(button));
+			return make_shared<MouseButtonDownEvent>(button);
 		}
 	} else {
 		throw CommandException("Invalid mouse event: " + str);
 	}
 }
 
+static EventPtr parseOsdControlEvent(
+		const string& str, const vector<string>& components)
+{
+#ifdef DEBUG
+	ad_printf("components.size(): %d\n", components.size());
+	for (unsigned cnt=0; cnt != components.size(); cnt++) {
+		ad_printf("component[%d]: %s\n", cnt, components[cnt].c_str());
+	}
+#endif
+	if (components.size() != 3) {
+		throw CommandException("Invalid OSDcontrol event: " + str);
+	}
+	string buttonName = components[1];
+	unsigned button;
+	if (buttonName == "LEFT") {
+		button = OsdControlEvent::LEFT_BUTTON;
+	} else if (buttonName == "RIGHT") {
+		button = OsdControlEvent::RIGHT_BUTTON;
+	} else if (buttonName == "UP") {
+		button = OsdControlEvent::UP_BUTTON;
+	} else if (buttonName == "DOWN") {
+		button = OsdControlEvent::DOWN_BUTTON;
+	} else if (buttonName == "A") {
+		button = OsdControlEvent::A_BUTTON;
+	} else if (buttonName == "B") {
+		button = OsdControlEvent::B_BUTTON;
+	} else {
+		throw CommandException("Invalid OSDcontrol event: " + str);
+	}
+	if (components[2] == "RELEASE") {
+		return make_shared<OsdControlReleaseEvent>(button, nullptr);
+	} else if (components[2] == "PRESS") {
+		return make_shared<OsdControlPressEvent>(button, nullptr);
+	}
+	else {
+		throw CommandException("Invalid OSDcontrol event: " + str);
+	}
+}
+
 static EventPtr parseJoystickEvent(
 		const string& str, const vector<string>& components)
 {
@@ -99,9 +150,9 @@ static EventPtr parseJoystickEvent(
 			throw CommandException("Invalid joystick button number: " + joyButtonString);
 		}
 		if (upDown(components[2])) {
-			return EventPtr(new JoystickButtonUpEvent(joystick, button));
+			return make_shared<JoystickButtonUpEvent>(joystick, button);
 		} else {
-			return EventPtr(new JoystickButtonDownEvent(joystick, button));
+			return make_shared<JoystickButtonDownEvent>(joystick, button);
 		}
 	} else if (StringOp::startsWith(components[1], "axis")) {
 		int axis;
@@ -113,7 +164,7 @@ static EventPtr parseJoystickEvent(
 		if (!StringOp::stringToInt(components[2], value) || (short(value) != value)) {
 			throw CommandException("Invalid value: " + components[2]);
 		}
-		return EventPtr(new JoystickAxisMotionEvent(joystick, axis, value));
+		return make_shared<JoystickAxisMotionEvent>(joystick, axis, value);
 	} else {
 		throw CommandException("Invalid joystick event: " + str);
 	}
@@ -126,7 +177,7 @@ static EventPtr parseFocusEvent(
 		throw CommandException("Invalid focus event: " + str);
 	}
 	bool gain = StringOp::stringToBool(components[1]);
-	return EventPtr(new FocusEvent(gain));
+	return make_shared<FocusEvent>(gain);
 }
 
 static EventPtr parseResizeEvent(
@@ -137,7 +188,7 @@ static EventPtr parseResizeEvent(
 	}
 	int x = StringOp::stringToInt(components[1]);
 	int y = StringOp::stringToInt(components[2]);
-	return EventPtr(new ResizeEvent(x, y));
+	return make_shared<ResizeEvent>(x, y);
 }
 
 static EventPtr parseQuitEvent(
@@ -146,13 +197,12 @@ static EventPtr parseQuitEvent(
 	if (components.size() != 1) {
 		throw CommandException("Invalid quit event: " + str);
 	}
-	return EventPtr(new QuitEvent());
+	return make_shared<QuitEvent>();
 }
 
 EventPtr createInputEvent(const string& str)
 {
-	vector<string> components;
-	Interpreter::splitList(str, components, 0);
+	auto components = Interpreter::splitList(str, nullptr);
 	if (components.empty()) {
 		throw CommandException("Invalid event: \"" + str + '\"');
 	}
@@ -171,6 +221,8 @@ EventPtr createInputEvent(const string& str)
 	} else if (components[0] == "command") {
 		return EventPtr();
 		//return parseCommandEvent(str, components);
+	} else if (components[0] == "OSDcontrol") {
+		return parseOsdControlEvent(str, components);
 	} else {
 		// fall back
 		return parseKeyEvent(components[0], 0);
