@@ -3,11 +3,9 @@
 #include "DummyDisk.hh"
 #include "RamDSKDiskImage.hh"
 #include "DirAsDSK.hh"
-#include "DSKDiskImage.hh"
 #include "CommandController.hh"
 #include "RecordedCommand.hh"
 #include "StateChangeDistributor.hh"
-#include "InputEvents.hh"
 #include "Scheduler.hh"
 #include "FilePool.hh"
 #include "File.hh"
@@ -21,7 +19,6 @@
 #include "CliComm.hh"
 #include "TclObject.hh"
 #include "EmuTime.hh"
-#include "checked_cast.hh"
 #include "serialize.hh"
 #include "serialize_stl.hh"
 #include "serialize_constr.hh"
@@ -49,7 +46,8 @@ private:
 
 DiskChanger::DiskChanger(MSXMotherBoard& board,
                          const string& driveName_,
-                         bool createCmd)
+                         bool createCmd,
+                         bool isDoubleSidedDrive)
 	: controller(board.getCommandController())
 	, stateChangeDistributor(&board.getStateChangeDistributor())
 	, scheduler(&board.getScheduler())
@@ -57,6 +55,7 @@ DiskChanger::DiskChanger(MSXMotherBoard& board,
 	, diskFactory(board.getReactor().getDiskFactory())
 	, manipulator(board.getReactor().getDiskManipulator())
 	, driveName(driveName_)
+	, doubleSidedDrive(isDoubleSidedDrive)
 {
 	init(board.getMachineID() + "::", createCmd);
 }
@@ -73,6 +72,7 @@ DiskChanger::DiskChanger(const string& driveName_,
 	, diskFactory(diskFactory_)
 	, manipulator(manipulator_)
 	, driveName(driveName_)
+	, doubleSidedDrive(true) // irrelevant, but needs a value
 {
 	init("", createCmd);
 }
@@ -181,9 +181,7 @@ void DiskChanger::stopReplay(EmuTime::param /*time*/)
 
 int DiskChanger::insertDisk(const string& filename)
 {
-	vector<TclObject> args;
-	args.push_back(TclObject("dummy"));
-	args.push_back(TclObject(filename));
+	vector<TclObject> args = { TclObject("dummy"), TclObject(filename) };
 	try {
 		insertDisk(args);
 		return 0;
@@ -251,29 +249,21 @@ void DiskCommand::execute(const vector<TclObject>& tokens, TclObject& result)
 		}
 
 	} else if (tokens[1].getString() == "ramdsk") {
-		vector<string> args;
-		args.push_back(diskChanger.getDriveName());
-		args.push_back(tokens[1].getString().str());
-		diskChanger.sendChangeDiskEvent(args);
+		diskChanger.sendChangeDiskEvent({
+			diskChanger.getDriveName(), tokens[1].getString().str()});
 	} else if (tokens[1].getString() == "-ramdsk") {
-		vector<string> args;
-		args.push_back(diskChanger.getDriveName());
-		args.push_back("ramdsk");
-		diskChanger.sendChangeDiskEvent(args);
+		diskChanger.sendChangeDiskEvent({
+			diskChanger.getDriveName(), "ramdsk"});
 		result.setString(
 			"Warning: use of '-ramdsk' is deprecated, instead use the 'ramdsk' subcommand");
 	} else if (tokens[1].getString() == "-eject") {
-		vector<string> args;
-		args.push_back(diskChanger.getDriveName());
-		args.push_back("eject");
-		diskChanger.sendChangeDiskEvent(args);
+		diskChanger.sendChangeDiskEvent({
+			diskChanger.getDriveName(), "eject"});
 		result.setString(
 			"Warning: use of '-eject' is deprecated, instead use the 'eject' subcommand");
 	} else if (tokens[1].getString() == "eject") {
-		vector<string> args;
-		args.push_back(diskChanger.getDriveName());
-		args.push_back("eject");
-		diskChanger.sendChangeDiskEvent(args);
+		diskChanger.sendChangeDiskEvent({
+			diskChanger.getDriveName(), "eject"});
 	} else {
 		int firstFileToken = 1;
 		if (tokens[1].getString() == "insert") {
@@ -284,8 +274,7 @@ void DiskCommand::execute(const vector<TclObject>& tokens, TclObject& result)
 			}
 		}
 		try {
-			vector<string> args;
-			args.push_back(diskChanger.getDriveName());
+			vector<string> args = { diskChanger.getDriveName() };
 			for (unsigned i = firstFileToken; i < tokens.size(); ++i) {
 				string_ref option = tokens[i].getString();
 				if (option == "-ips") {
@@ -385,12 +374,11 @@ void DiskChanger::serialize(Archive& ar, unsigned version)
 					name = file->getURL();
 				}
 			}
-			vector<TclObject> args;
-			args.push_back(TclObject("dummy"));
-			args.push_back(TclObject(name));
+			vector<TclObject> args =
+				{ TclObject("dummy"), TclObject(name) };
 			for (auto& p : patches) {
 				p.updateAfterLoadState();
-				args.push_back(TclObject(p.getResolved())); // TODO
+				args.emplace_back(p.getResolved()); // TODO
 			}
 
 			try {
