@@ -8,13 +8,12 @@
 #include "StringOp.hh"
 #include "FileOperations.hh"
 #include "CommandException.hh"
+#include "array_ref.hh"
 #include "memory.hh"
 #include "unreachable.hh"
 #include <cassert>
-#include <deque>
 
 using std::unique_ptr;
-using std::deque;
 using std::set;
 using std::string;
 using std::vector;
@@ -33,7 +32,7 @@ unique_ptr<DiskChanger> NowindCommand::createDiskChanger(
 	const string& basename, unsigned n, MSXMotherBoard& motherBoard) const
 {
 	string name = StringOp::Builder() << basename << n + 1;
-	return make_unique<DiskChanger>(motherBoard, name, false);
+	return make_unique<DiskChanger>(motherBoard, name, false, true);
 }
 
 unsigned NowindCommand::searchRomdisk(const NowindInterface::Drives& drives) const
@@ -135,7 +134,7 @@ string NowindCommand::execute(const vector<string>& tokens)
 	string error;
 
 	// actually parse the commandline
-	deque<string> args(tokens.begin() + 1, tokens.end());
+	array_ref<string> args(&tokens[1], tokens.size() - 1);
 	while (error.empty() && !args.empty()) {
 		bool createDrive = false;
 		string image;
