@@ -77,12 +77,7 @@ byte NowindHost::peek() const
 // receive:  msx <- pc
 byte NowindHost::read()
 {
-	if (!isDataAvailable()) {
-		return 0xff;
-	}
-	byte result = hostToMsxFifo.front();
-	hostToMsxFifo.pop_front();
-	return result;
+	return isDataAvailable() ? hostToMsxFifo.pop_front() : 0xFF;
 }
 
 bool NowindHost::isDataAvailable() const
@@ -168,8 +163,8 @@ void NowindHost::write(byte data, unsigned time)
 
 void NowindHost::msxReset()
 {
-	for (unsigned i = 0; i < MAX_DEVICES; ++i) {
-		devices[i].fs.reset();
+	for (auto& dev : devices) {
+		dev.fs.reset();
 	}
 	DBERR("MSX reset\n");
 }
