@@ -1,19 +1,17 @@
-// $Id: ZipFileAdapter.cc 11747 2010-11-11 07:15:09Z m9710797 $
-
 #include "ZipFileAdapter.hh"
 #include "ZlibInflate.hh"
 #include "FileException.hh"
 
 namespace openmsx {
 
-ZipFileAdapter::ZipFileAdapter(std::auto_ptr<FileBase> file_)
-	: CompressedFileAdapter(file_)
+ZipFileAdapter::ZipFileAdapter(std::unique_ptr<FileBase> file_)
+	: CompressedFileAdapter(std::move(file_))
 {
 }
 
 void ZipFileAdapter::decompress(FileBase& file, Decompressed& decompressed)
 {
-	unsigned size;
+	size_t size;
 	const byte* data = file.mmap(size);
 	ZlibInflate zlib(data, size);
 
