@@ -8,7 +8,6 @@
 #include "serialize.hh"
 #include "serialize_meta.hh"
 #include "memory.hh"
-#include <cassert>
 
 using std::string;
 using std::shared_ptr;
@@ -19,10 +18,10 @@ class KeyJoyState : public StateChange
 {
 public:
 	KeyJoyState() {} // for serialize
-	KeyJoyState(EmuTime::param time, const string& name_,
+	KeyJoyState(EmuTime::param time, string name_,
 	            byte press_, byte release_)
 		: StateChange(time)
-		, name(name_), press(press_), release(release_) {}
+		, name(std::move(name_)), press(press_), release(release_) {}
 	const string& getName() const { return name; }
 	byte getPress()   const { return press; }
 	byte getRelease() const { return release; }
