@@ -20,21 +20,21 @@ KeyboardSettings::KeyboardSettings(CommandController& commandController)
 		"Automatically toggle the CODE/KANA lock, based on the characters entered on the host keyboard",
 		true))
 {
-	EnumSetting<Keys::KeyCode>::Map allowedKeys;
-	allowedKeys.push_back(std::make_pair("RALT",        Keys::K_RALT));
-	allowedKeys.push_back(std::make_pair("MENU",        Keys::K_MENU));
-	allowedKeys.push_back(std::make_pair("RCTRL",       Keys::K_RCTRL));
-	allowedKeys.push_back(std::make_pair("HENKAN_MODE", Keys::K_HENKAN_MODE));
-	allowedKeys.push_back(std::make_pair("RSHIFT",      Keys::K_RSHIFT));
-	allowedKeys.push_back(std::make_pair("RMETA",       Keys::K_RMETA));
-	allowedKeys.push_back(std::make_pair("LMETA",       Keys::K_LMETA));
-	allowedKeys.push_back(std::make_pair("LSUPER",      Keys::K_LSUPER));
-	allowedKeys.push_back(std::make_pair("RSUPER",      Keys::K_RSUPER));
-	allowedKeys.push_back(std::make_pair("HELP",        Keys::K_HELP));
-	allowedKeys.push_back(std::make_pair("UNDO",        Keys::K_UNDO));
-	allowedKeys.push_back(std::make_pair("END",         Keys::K_END));
-	allowedKeys.push_back(std::make_pair("PAGEUP",      Keys::K_PAGEUP));
-	allowedKeys.push_back(std::make_pair("PAGEDOWN",    Keys::K_PAGEDOWN));
+	EnumSetting<Keys::KeyCode>::Map allowedKeys = {
+		{ "RALT",        Keys::K_RALT },
+		{ "MENU",        Keys::K_MENU },
+		{ "RCTRL",       Keys::K_RCTRL },
+		{ "HENKAN_MODE", Keys::K_HENKAN_MODE },
+		{ "RSHIFT",      Keys::K_RSHIFT },
+		{ "RMETA",       Keys::K_RMETA },
+		{ "LMETA",       Keys::K_LMETA },
+		{ "LSUPER",      Keys::K_LSUPER },
+		{ "RSUPER",      Keys::K_RSUPER },
+		{ "HELP",        Keys::K_HELP },
+		{ "UNDO",        Keys::K_UNDO },
+		{ "END",         Keys::K_END },
+		{ "PAGEUP",      Keys::K_PAGEUP },
+		{ "PAGEDOWN",    Keys::K_PAGEDOWN } };
 	codeKanaHostKey = make_unique<EnumSetting<Keys::KeyCode>>(
 		commandController, "kbd_code_kana_host_key",
 		"Host key that maps to the MSX CODE/KANA key. Please note that the HENKAN_MODE key only exists on Japanese host keyboards)",
@@ -55,17 +55,17 @@ KeyboardSettings::KeyboardSettings(CommandController& commandController)
 		"Host key that maps to deadkey 3. Only applicable to Brazilian Sharp Hotbit MSX models",
 		Keys::K_PAGEDOWN, allowedKeys);
 
-	EnumSetting<KpEnterMode>::Map kpEnterModeMap;
-	kpEnterModeMap.push_back(std::make_pair("KEYPAD_COMMA", MSX_KP_COMMA));
-	kpEnterModeMap.push_back(std::make_pair("ENTER",        MSX_ENTER));
+	EnumSetting<KpEnterMode>::Map kpEnterModeMap = {
+		{ "KEYPAD_COMMA", MSX_KP_COMMA },
+		{ "ENTER",        MSX_ENTER } };
 	kpEnterMode = make_unique<EnumSetting<KpEnterMode>>(
 		commandController, "kbd_numkeypad_enter_key",
 		"MSX key that the enter key on the host numeric keypad must map to",
 		MSX_KP_COMMA, kpEnterModeMap);
 
-	EnumSetting<MappingMode>::Map mappingModeMap;
-	mappingModeMap.push_back(std::make_pair("KEY",       KEY_MAPPING));
-	mappingModeMap.push_back(std::make_pair("CHARACTER", CHARACTER_MAPPING));
+	EnumSetting<MappingMode>::Map mappingModeMap = {
+		{ "KEY",       KEY_MAPPING },
+		{ "CHARACTER", CHARACTER_MAPPING } };
 	mappingMode = make_unique<EnumSetting<MappingMode>>(
 		commandController, "kbd_mapping_mode",
 		"Keyboard mapping mode",
