@@ -1,9 +1,8 @@
-// $Id: MSXPac.cc 12527 2012-05-17 17:34:11Z m9710797 $
-
 #include "MSXPac.hh"
 #include "SRAM.hh"
 #include "CacheLine.hh"
 #include "serialize.hh"
+#include "memory.hh"
 
 namespace openmsx {
 
@@ -11,7 +10,8 @@ static const char* const PAC_Header = "PAC2 BACKUP DATA";
 
 MSXPac::MSXPac(const DeviceConfig& config)
 	: MSXDevice(config)
-	, sram(new SRAM(getName() + " SRAM", 0x1FFE, config, PAC_Header))
+	, sram(make_unique<SRAM>(
+		getName() + " SRAM", 0x1FFE, config, PAC_Header))
 {
 	reset(EmuTime::dummy());
 }
@@ -53,7 +53,7 @@ const byte* MSXPac::getReadCacheLine(word address) const
 		if (address < (0x1FFE & CacheLine::HIGH)) {
 			return &(*sram)[address];
 		} else if (address == (0x1FFE & CacheLine::HIGH)) {
-			return NULL;
+			return nullptr;
 		} else {
 			return unmappedRead;
 		}
@@ -85,10 +85,10 @@ byte* MSXPac::getWriteCacheLine(word address) const
 {
 	address &= 0x3FFF;
 	if (address == (0x1FFE & CacheLine::HIGH)) {
-		return NULL;
+		return nullptr;
 	}
 	if (sramEnabled && (address < 0x1FFE)) {
-		return NULL;
+		return nullptr;
 	} else {
 		return unmappedWrite;
 	}
