@@ -1,5 +1,3 @@
-// $Id: RomAscii8kB.cc 12527 2012-05-17 17:34:11Z m9710797 $
-
 // ASCII 8kB cartridges
 //
 // this type is used in many japanese-only cartridges.
@@ -17,8 +15,8 @@
 
 namespace openmsx {
 
-RomAscii8kB::RomAscii8kB(const DeviceConfig& config, std::auto_ptr<Rom> rom)
-	: Rom8kBBlocks(config, rom)
+RomAscii8kB::RomAscii8kB(const DeviceConfig& config, std::unique_ptr<Rom> rom)
+	: Rom8kBBlocks(config, std::move(rom))
 {
 	reset(EmuTime::dummy());
 }
@@ -45,7 +43,7 @@ void RomAscii8kB::writeMem(word address, byte value, EmuTime::param /*time*/)
 byte* RomAscii8kB::getWriteCacheLine(word address) const
 {
 	if ((0x6000 <= address) && (address < 0x8000)) {
-		return NULL;
+		return nullptr;
 	} else {
 		return unmappedWrite;
 	}
