@@ -5,7 +5,6 @@
 #include "FileContext.hh"
 #include "File.hh"
 #include "FileOperations.hh"
-#include "FileException.hh"
 #include "GlobalCommandController.hh"
 #include "CliComm.hh"
 #include "StringOp.hh"
@@ -74,8 +73,6 @@ private:
 		YEAR,
 		COUNTRY,
 		GENMSXID,
-		SW_REMARK,
-		SW_TEXT,
 		DUMP_REMARK,
 		DUMP_TEXT,
 		DUMP,
@@ -88,7 +85,7 @@ private:
 	};
 
 	struct Dump {
-		string remarks;
+		string_ref remark;
 		Sha1Sum hash;
 		string_ref origData;
 		RomType type;
@@ -102,7 +99,6 @@ private:
 	string_ref systemID;
 	string_ref type;
 	string_ref startVal;
-	string_ref algo;
 
 	vector<Dump> dumps;
 	string_ref system;
@@ -110,7 +106,6 @@ private:
 	string_ref company;
 	string_ref year;
 	string_ref country;
-	string remarks;
 	int genMSXid;
 
 	State state;
@@ -129,10 +124,9 @@ void DBParser::start(string_ref tag)
 	case BEGIN:
 		if (tag == "softwaredb") {
 			state = SOFTWAREDB;
-		} else {
-			throw MSXException("Expected <softwaredb> as root tag.");
+			return;
 		}
-		break;
+		throw MSXException("Expected <softwaredb> as root tag.");
 	case SOFTWAREDB:
 		if (tag == "software") {
 			system.clear();
@@ -140,80 +134,126 @@ void DBParser::start(string_ref tag)
 			company.clear();
 			year.clear();
 			country.clear();
-			remarks.clear();
 			genMSXid = 0;
 			dumps.clear();
 			state = SOFTWARE;
-		} else {
-			++unknownLevel;
+			return;
 		}
 		break;
-	case SOFTWARE:
-		if        (tag == "system") {
-			state = SYSTEM;
-		} else if (tag == "title") {
-			state = TITLE;
-		} else if (tag == "company") {
-			state = COMPANY;
-		} else if (tag == "year") {
-			state = YEAR;
-		} else if (tag == "country") {
-			state = COUNTRY;
-		} else if (tag == "remark") {
-			state = SW_REMARK;
-		} else if (tag == "genmsxid") {
-			state = GENMSXID;
-		} else if (tag == "dump") {
-			dumps.resize(dumps.size() + 1);
-			dumps.back().type = ROM_UNKNOWN;
-			dumps.back().origValue = false;
-			state = DUMP;
-		} else {
-			++unknownLevel;
+	case SOFTWARE: {
+		char c = tag.front();
+		tag.pop_front();
+		switch (c) {
+		case 's':
+			if (tag == "ystem") {
+				state = SYSTEM;
+				return;
+			}
+			break;
+		case 't':
+			if (tag == "itle") {
+				state = TITLE;
+				return;
+			}
+			break;
+		case 'c':
+			if (tag == "ompany") {
+				state = COMPANY;
+				return;
+			} else if (tag == "ountry") {
+				state = COUNTRY;
+				return;
+			}
+			break;
+		case 'y':
+			if (tag == "ear") {
+				state = YEAR;
+				return;
+			}
+			break;
+		case 'g':
+			if (tag == "enmsxid") {
+				state = GENMSXID;
+				return;
+			}
+			break;
+		case 'd':
+			if (tag == "ump") {
+				dumps.resize(dumps.size() + 1);
+				dumps.back().type = ROM_UNKNOWN;
+				dumps.back().origValue = false;
+				state = DUMP;
+				return;
+			}
+			break;
 		}
 		break;
-	case DUMP:
-		if        (tag == "original") {
-			dumps.back().origValue = false;
-			state = ORIGINAL;
-		} else if (tag == "megarom") {
-			type.clear();
-			startVal.clear();
-			state = ROM;
-		} else if (tag == "rom") {
-			type = "Mirrored";
-			startVal.clear();
-			state = ROM;
-		} else {
-			++unknownLevel;
+	}
+	case DUMP: {
+		char c = tag.front();
+		tag.pop_front();
+		switch (c) {
+		case 'o':
+			if (tag == "riginal") {
+				dumps.back().origValue = false;
+				state = ORIGINAL;
+				return;
+			}
+			break;
+		case 'm':
+			if (tag == "egarom") {
+				type.clear();
+				startVal.clear();
+				state = ROM;
+				return;
+			}
+			break;
+		case 'r':
+			if (tag == "om") {
+				type = "Mirrored";
+				startVal.clear();
+				state = ROM;
+				return;
+			}
+			break;
 		}
 		break;
-	case ROM:
-		if        (tag == "type") {
-			state = TYPE;
-		} else if (tag == "start") {
-			state = START;
-		} else if (tag == "remark") {
-			state = DUMP_REMARK;
-		} else if (tag == "hash") {
-			algo.clear();
-			state = HASH;
-		} else {
-			++unknownLevel;
-		}
-		break;
-	case SW_REMARK:
-		if (tag == "text") {
-			state = SW_TEXT;
-		} else {
-			++unknownLevel;
+	}
+	case ROM: {
+		char c = tag.front();
+		tag.pop_front();
+		switch (c) {
+		case 't':
+			if (tag == "ype") {
+				state = TYPE;
+				return;
+			}
+			break;
+		case 's':
+			if (tag == "tart") {
+				state = START;
+				return;
+			}
+			break;
+		case 'r':
+			if (tag == "emark") {
+				state = DUMP_REMARK;
+				return;
+			}
+			break;
+		case 'h':
+			if (tag == "ash") {
+				state = HASH;
+				return;
+			}
+			break;
 		}
 		break;
+	}
 	case DUMP_REMARK:
 		if (tag == "text") {
 			state = DUMP_TEXT;
-		} else {
-			++unknownLevel;
+			return;
 		}
 		break;
 	case SYSTEM:
@@ -226,9 +266,7 @@ void DBParser::start(string_ref tag)
 	case TYPE:
 	case START:
 	case HASH:
-	case SW_TEXT:
 	case DUMP_TEXT:
-		++unknownLevel;
 		break;
 
 	case END:
@@ -237,6 +275,8 @@ void DBParser::start(string_ref tag)
 	default:
 		UNREACHABLE;
 	}
+
+	++unknownLevel;
 }
 
 void DBParser::attribute(string_ref name, string_ref value)
@@ -250,10 +290,6 @@ void DBParser::attribute(string_ref name, string_ref value)
 		}
 		break;
 	case HASH:
-		if (name == "algo") {
-			algo = value;
-		}
-		break;
 	case BEGIN:
 	case SOFTWAREDB:
 	case SOFTWARE:
@@ -263,8 +299,6 @@ void DBParser::attribute(string_ref name, string_ref value)
 	case YEAR:
 	case COUNTRY:
 	case GENMSXID:
-	case SW_REMARK:
-	case SW_TEXT:
 	case DUMP_REMARK:
 	case DUMP_TEXT:
 	case DUMP:
@@ -278,13 +312,6 @@ void DBParser::attribute(string_ref name, string_ref value)
 	}
 }
 
-static void joinRemarks(string& result, string_ref extra)
-{
-	if (extra.empty()) return;
-	if (!result.empty()) result += '\n';
-	result.append(extra.data(), extra.size());
-}
-
 void DBParser::text(string_ref text)
 {
 	if (unknownLevel) return;
@@ -323,17 +350,11 @@ void DBParser::text(string_ref text)
 		startVal = text;
 		break;
 	case HASH:
-		if (algo == "sha1") {
-			dumps.back().hash = Sha1Sum(text);
-		}
-		break;
-	case SW_REMARK:
-	case SW_TEXT:
-		joinRemarks(remarks, text);
+		dumps.back().hash = Sha1Sum(text);
 		break;
 	case DUMP_REMARK:
 	case DUMP_TEXT:
-		joinRemarks(dumps.back().remarks, text);
+		dumps.back().remark = text;
 		break;
 	case BEGIN:
 	case SOFTWAREDB:
@@ -356,12 +377,10 @@ void DBParser::addEntries()
 	}
 
 	for (auto& d : dumps) {
-		string r = remarks;
-		joinRemarks(r, d.remarks);
-		db.push_back(std::make_pair(d.hash, RomInfo(
+		db.emplace_back(d.hash, RomInfo(
 			title, year, company, country,
-			d.origValue, d.origData, r, d.type,
-			genMSXid)));
+			d.origValue, d.origData, d.remark, d.type,
+			genMSXid));
 	}
 }
 
@@ -465,12 +484,8 @@ void DBParser::stop()
 	case YEAR:
 	case COUNTRY:
 	case GENMSXID:
-	case SW_REMARK:
 		state = SOFTWARE;
 		break;
-	case SW_TEXT:
-		state = SW_REMARK;
-		break;
 	case DUMP:
 		if (dumps.back().hash.empty()) {
 			// no sha1 sum specified, drop this dump
@@ -565,7 +580,7 @@ RomDatabase::RomDatabase(GlobalCommandController& commandController, CliComm& cl
 	for (auto& p : paths) {
 		string filename = FileOperations::join(p, "softwaredb.xml");
 		try {
-			buffers.push_back(MemBuffer<char>());
+			buffers.emplace_back();
 			parseDB(cliComm, filename, buffers.back(), db, unknownTypes);
 		} catch (rapidsax::ParseError& e) {
 			cliComm.printWarning(StringOp::Builder() <<
