@@ -1,5 +1,3 @@
-// $Id: RomPadial8kB.cc 12527 2012-05-17 17:34:11Z m9710797 $
-
 // Padial 8kB
 //
 // The address to change banks:
@@ -14,8 +12,8 @@
 
 namespace openmsx {
 
-RomPadial8kB::RomPadial8kB(const DeviceConfig& config, std::auto_ptr<Rom> rom)
-	: RomAscii8kB(config, rom)
+RomPadial8kB::RomPadial8kB(const DeviceConfig& config, std::unique_ptr<Rom> rom)
+	: RomAscii8kB(config, std::move(rom))
 {
 	reset(EmuTime::dummy());
 }
