@@ -89,8 +89,10 @@ void MidiInReader::run()
 		}
 		assert(isPluggedIn());
 
-		ScopedLock l(lock);
-		queue.push_back(buf);
+		{
+			ScopedLock l(lock);
+			queue.push_back(buf);
+		}
 		eventDistributor.distributeEvent(
 			std::make_shared<SimpleEvent>(OPENMSX_MIDI_IN_READER_EVENT));
 	}
@@ -101,6 +103,7 @@ void MidiInReader::signal(EmuTime::param time)
 {
 	auto connector = static_cast<MidiInConnector*>(getConnector());
 	if (!connector->acceptsData()) {
+		ScopedLock l(lock);
 		queue.clear();
 		return;
 	}
@@ -108,10 +111,12 @@ void MidiInReader::signal(EmuTime::param time)
 		return;
 	}
 
-	ScopedLock l(lock);
-	if (queue.empty()) return;
-	byte data = queue.front();
-	queue.pop_front();
+	byte data;
+	{
+		ScopedLock l(lock);
+		if (queue.empty()) return;
+		data = queue.pop_front();
+	}
 	connector->recvByte(data, time);
 }
 
@@ -122,7 +127,7 @@ int MidiInReader::signalEvent(const std::shared_ptr<const Event>& /*event*/)
 		signal(scheduler.getCurrentTime());
 	} else {
 		ScopedLock l(lock);
-		queue.empty();
+		queue.clear();
 	}
 	return 0;
 }
