@@ -1,10 +1,9 @@
-// $Id: MidiOutConnector.cc 12630 2012-06-14 20:17:01Z m9710797 $
-
 #include "MidiOutConnector.hh"
 #include "MidiOutDevice.hh"
 #include "DummyMidiOutDevice.hh"
 #include "checked_cast.hh"
 #include "serialize.hh"
+#include "memory.hh"
 
 using std::string;
 
@@ -13,7 +12,7 @@ namespace openmsx {
 MidiOutConnector::MidiOutConnector(PluggingController& pluggingController,
                                    string_ref name)
 	: Connector(pluggingController, name,
-	            std::auto_ptr<Pluggable>(new DummyMidiOutDevice()))
+	            make_unique<DummyMidiOutDevice>())
 {
 }
 
