@@ -112,6 +112,7 @@ void RS232Tester::signal(EmuTime::param time)
 {
 	auto connector = static_cast<RS232Connector*>(getConnector());
 	if (!connector->acceptsData()) {
+		ScopedLock l(lock);
 		queue.clear();
 		return;
 	}
@@ -119,9 +120,7 @@ void RS232Tester::signal(EmuTime::param time)
 
 	ScopedLock l(lock);
 	if (queue.empty()) return;
-	byte data = queue.front();
-	queue.pop_front();
-	connector->recvByte(data, time);
+	connector->recvByte(queue.pop_front(), time);
 }
 
 // EventListener
@@ -131,7 +130,7 @@ int RS232Tester::signalEvent(const std::shared_ptr<const Event>& /*event*/)
 		signal(scheduler.getCurrentTime());
 	} else {
 		ScopedLock l(lock);
-		queue.empty();
+		queue.clear();
 	}
 	return 0;
 }
