@@ -1,5 +1,3 @@
-// $Id: SettingsManager.cc 12805 2012-08-13 19:26:18Z m9710797 $
-
 #include "SettingsManager.hh"
 #include "GlobalCommandController.hh"
 #include "Command.hh"
@@ -8,9 +6,10 @@
 #include "Setting.hh"
 #include "CommandException.hh"
 #include "XMLElement.hh"
+#include "KeyRange.hh"
+#include "memory.hh"
 #include <cassert>
 
-using std::set;
 using std::string;
 using std::vector;
 
@@ -55,11 +54,14 @@ private:
 
 
 SettingsManager::SettingsManager(GlobalCommandController& commandController)
-	: settingInfo   (new SettingInfo(
-	                    commandController.getOpenMSXInfoCommand(), *this))
-	, setCompleter  (new SetCompleter    (commandController, *this))
-	, incrCompleter (new SettingCompleter(commandController, *this, "incr"))
-	, unsetCompleter(new SettingCompleter(commandController, *this, "unset"))
+	: settingInfo(make_unique<SettingInfo>(
+		commandController.getOpenMSXInfoCommand(), *this))
+	, setCompleter(make_unique<SetCompleter>(
+		commandController, *this))
+	, incrCompleter(make_unique<SettingCompleter>(
+		commandController, *this, "incr"))
+	, unsetCompleter(make_unique<SettingCompleter>(
+		commandController, *this, "unset"))
 {
 }
 
@@ -68,73 +70,55 @@ SettingsManager::~SettingsManager()
 	assert(settingsMap.empty());
 }
 
-void SettingsManager::registerSetting(Setting& setting, string_ref name)
+void SettingsManager::registerSetting(BaseSetting& setting, string_ref name)
 {
 	assert(settingsMap.find(name) == settingsMap.end());
 	settingsMap[name] = &setting;
 }
 
-void SettingsManager::unregisterSetting(Setting& /*setting*/, string_ref name)
+void SettingsManager::unregisterSetting(BaseSetting& /*setting*/, string_ref name)
 {
 	assert(settingsMap.find(name) != settingsMap.end());
 	settingsMap.erase(name);
 }
 
-Setting* SettingsManager::findSetting(string_ref name) const
+BaseSetting* SettingsManager::findSetting(string_ref name) const
 {
-	SettingsMap::const_iterator it = settingsMap.find(name);
-	return (it != settingsMap.end()) ? it->second : NULL;
+	auto it = settingsMap.find(name);
+	return (it != settingsMap.end()) ? it->second : nullptr;
 }
 
 // Helper functions for setting commands
 
-void SettingsManager::getSettingNames(set<string>& result) const
+BaseSetting& SettingsManager::getByName(string_ref cmd, string_ref name) const
 {
-	for (SettingsMap::const_iterator it = settingsMap.begin();
-	     it != settingsMap.end(); ++it) {
-		result.insert(it->first().str());
+	if (auto* setting = findSetting(name)) {
+		return *setting;
 	}
-}
-
-Setting& SettingsManager::getByName(string_ref cmd, string_ref name) const
-{
-	Setting* setting = getByName(name);
-	if (!setting) {
-		throw CommandException(cmd + ": " + name +
-		                       ": no such setting");
-	}
-	return *setting;
-}
-
-Setting* SettingsManager::getByName(string_ref name) const
-{
-	SettingsMap::const_iterator it = settingsMap.find(name);
-	return it != settingsMap.end() ? it->second : NULL;
+	throw CommandException(cmd + ": " + name + ": no such setting");
 }
 
 void SettingsManager::loadSettings(const XMLElement& config)
 {
 	// restore default values
-	for (SettingsMap::const_iterator it = settingsMap.begin();
-	     it != settingsMap.end(); ++it) {
-		const Setting& setting = *it->second;
+	for (auto& p : settingsMap) {
+		auto& setting = *p.second;
 		if (setting.needLoadSave()) {
-			it->second->restoreDefault();
+			setting.setString(setting.getRestoreValue());
 		}
 	}
 
 	// load new values
-	const XMLElement* settings = config.findChild("settings");
+	auto* settings = config.findChild("settings");
 	if (!settings) return;
-	for (SettingsMap::const_iterator it = settingsMap.begin();
-	     it != settingsMap.end(); ++it) {
-		string_ref name = it->first();
-		Setting& setting = *it->second;
+	for (auto& p : settingsMap) {
+		auto name = p.first();
+		auto& setting = *p.second;
 		if (!setting.needLoadSave()) continue;
-		if (const XMLElement* elem = settings->findChildWithAttribute(
+		if (auto* elem = settings->findChildWithAttribute(
 		                                     "setting", "id", name)) {
 			try {
-				setting.changeValueString(elem->getData());
+				setting.setString(elem->getData());
 			} catch (MSXException&) {
 				// ignore, keep default value
 			}
@@ -142,15 +126,8 @@ void SettingsManager::loadSettings(const XMLElement& config)
 	}
 }
 
-void SettingsManager::saveSettings(XMLElement& config) const
-{
-	for (SettingsMap::const_iterator it = settingsMap.begin();
-	     it != settingsMap.end(); ++it) {
-		it->second->sync(config);
-	}
-}
 
-// SettingInfo implementation
+// class SettingInfo
 
 SettingInfo::SettingInfo(InfoCommand& openMSXInfoCommand,
                          SettingsManager& manager_)
@@ -162,18 +139,16 @@ SettingInfo::SettingInfo(InfoCommand& openMSXInfoCommand,
 void SettingInfo::execute(
 	const vector<TclObject>& tokens, TclObject& result) const
 {
-	const SettingsManager::SettingsMap& settingsMap = manager.settingsMap;
+	auto& settingsMap = manager.settingsMap;
 	switch (tokens.size()) {
 	case 2:
-		for (SettingsManager::SettingsMap::const_iterator it =
-		       settingsMap.begin(); it != settingsMap.end(); ++it) {
-			result.addListElement(it->first());
+		for (auto& p : settingsMap) {
+			result.addListElement(p.first());
 		}
 		break;
 	case 3: {
-		string_ref name = tokens[2].getString();
-		SettingsManager::SettingsMap::const_iterator it =
-			settingsMap.find(name);
+		const auto& name = tokens[2].getString();
+		auto it = settingsMap.find(name);
 		if (it == settingsMap.end()) {
 			throw CommandException("No such setting: " + name);
 		}
@@ -195,18 +170,14 @@ string SettingInfo::help(const vector<string>& /*tokens*/) const
 
 void SettingInfo::tabCompletion(vector<string>& tokens) const
 {
-	switch (tokens.size()) {
-	case 3: { // complete setting name
-		set<string> settings;
-		manager.getSettingNames(settings);
-		completeString(tokens, settings);
-		break;
-	}
+	if (tokens.size() == 3) {
+		// complete setting name
+		completeString(tokens, keys(manager.settingsMap));
 	}
 }
 
 
-// SetCompleter implementation:
+// class SetCompleter
 
 SetCompleter::SetCompleter(CommandController& commandController,
                            SettingsManager& manager_)
@@ -229,17 +200,13 @@ string SetCompleter::help(const vector<string>& tokens) const
 void SetCompleter::tabCompletion(vector<string>& tokens) const
 {
 	switch (tokens.size()) {
-	case 2: {
+	case 2:
 		// complete setting name
-		set<string> settings;
-		manager.getSettingNames(settings);
-		completeString(tokens, settings, false); // case insensitive
+		completeString(tokens, keys(manager.settingsMap), false); // case insensitive
 		break;
-	}
 	case 3: {
 		// complete setting value
-		SettingsManager::SettingsMap::iterator it =
-			manager.settingsMap.find(tokens[1]);
+		auto it = manager.settingsMap.find(tokens[1]);
 		if (it != manager.settingsMap.end()) {
 			it->second->tabCompletion(tokens);
 		}
@@ -249,7 +216,7 @@ void SetCompleter::tabCompletion(vector<string>& tokens) const
 }
 
 
-// SettingCompleter implementation
+// class SettingCompleter
 
 SettingCompleter::SettingCompleter(
 		CommandController& commandController, SettingsManager& manager_,
@@ -266,14 +233,9 @@ string SettingCompleter::help(const vector<string>& /*tokens*/) const
 
 void SettingCompleter::tabCompletion(vector<string>& tokens) const
 {
-	switch (tokens.size()) {
-	case 2: {
+	if (tokens.size() == 2) {
 		// complete setting name
-		set<string> settings;
-		manager.getSettingNames(settings);
-		completeString(tokens, settings);
-		break;
-	}
+		completeString(tokens, keys(manager.settingsMap));
 	}
 }
 
