@@ -1,5 +1,3 @@
-// $Id: WavData.cc 12097 2011-04-10 20:50:38Z mthuurne $
-
 #include "WavData.hh"
 #include "MSXException.hh"
 #include "StringOp.hh"
@@ -20,7 +18,7 @@ WavData::WavData(const string& filename, unsigned wantedBits, unsigned wantedFre
 	SDL_AudioSpec wavSpec;
 	Uint8* wavBuf;
 	Uint32 wavLen;
-	if (SDL_LoadWAV(filename.c_str(), &wavSpec, &wavBuf, &wavLen) == NULL) {
+	if (!SDL_LoadWAV(filename.c_str(), &wavSpec, &wavBuf, &wavLen)) {
 		throw MSXException(StringOp::Builder() <<
 			"WavData error: " << SDL_GetError());
 	}
