@@ -1,5 +1,3 @@
-// $Id: YMF278.cc 12665 2012-06-24 22:05:16Z manuelbi $
-
 // Based on ymf278b.c written by R. Belmont and O. Galibert
 
 // This class doesn't model a full YMF278b chip. Instead it only models the
@@ -19,6 +17,7 @@
 #include "StringOp.hh"
 #include "serialize.hh"
 #include "likely.hh"
+#include "memory.hh"
 #include <algorithm>
 #include <cmath>
 #include <cstring>
@@ -131,8 +130,8 @@ private:
 	void keyOnHelper(YMF278Slot& slot);
 
 	MSXMotherBoard& motherBoard;
-	const std::auto_ptr<DebugRegisters> debugRegisters;
-	const std::auto_ptr<DebugMemory>    debugMemory;
+	const std::unique_ptr<DebugRegisters> debugRegisters;
+	const std::unique_ptr<DebugMemory>    debugMemory;
 
 	YMF278Slot slots[24];
 
@@ -144,7 +143,7 @@ private:
 	int fm_l, fm_r;
 	int pcm_l, pcm_r;
 
-	const std::auto_ptr<Rom> rom;
+	const std::unique_ptr<Rom> rom;
 	MemBuffer<byte> ram;
 
 	/** Precalculated attenuation values with some margin for
@@ -286,7 +285,7 @@ static const int vib_depth[8] = {
 #undef O
 
 
-#define SC(db) unsigned(db * (2.0 / ENV_STEP))
+#define SC(db) int(db * (2.0 / ENV_STEP))
 static const int am_depth[8] = {
 	SC(0),	   SC(1.781), SC(2.906), SC(3.656),
 	SC(4.406), SC(5.906), SC(7.406), SC(11.91)
@@ -588,7 +587,7 @@ void YMF278::Impl::generateChannels(int** bufs, unsigned num)
 		// TODO update internal state, even if muted
 		// TODO also mute individual channels
 		for (int i = 0; i < 24; ++i) {
-			bufs[i] = 0;
+			bufs[i] = nullptr;
 		}
 		return;
 	}
@@ -877,9 +876,11 @@ YMF278::Impl::Impl(YMF278& self, const std::string& name, int ramSize,
 	: ResampledSoundDevice(config.getMotherBoard(), name, "MoonSound wave-part",
 	                       24, true)
 	, motherBoard(config.getMotherBoard())
-	, debugRegisters(new DebugRegisters(self, motherBoard, getName()))
-	, debugMemory   (new DebugMemory   (self, motherBoard, getName()))
-	, rom(new Rom(name + " ROM", "rom", config))
+	, debugRegisters(make_unique<DebugRegisters>(
+		self, motherBoard, getName()))
+	, debugMemory(make_unique<DebugMemory>(
+		self, motherBoard, getName()))
+	, rom(make_unique<Rom>(name + " ROM", "rom", config))
 	, ram(ramSize * 1024) // in kB
 {
 	if (rom->getSize() != 0x200000) { // 2MB
@@ -1223,7 +1224,7 @@ void DebugMemory::write(unsigned address, byte value)
 // class YMF278
 
 YMF278::YMF278(const std::string& name, int ramSize, const DeviceConfig& config)
-	: pimpl(new Impl(*this, name, ramSize, config))
+	: pimpl(make_unique<Impl>(*this, name, ramSize, config))
 {
 }
 
