@@ -1,5 +1,3 @@
-// $Id: Alarm.cc 11609 2010-07-22 21:46:22Z m9710797 $
-
 #include "Alarm.hh"
 #include "Timer.hh"
 #include "Semaphore.hh"
@@ -49,9 +47,8 @@ private:
 	static unsigned timerCallback(unsigned interval, void* param);
 	unsigned timerCallback2();
 
-	typedef std::vector<Alarm*> Alarms;
-	Alarms alarms;
-	long long time;
+	std::vector<Alarm*> alarms;
+	int64_t time;
 	SDL_TimerID id;
 	Semaphore sem;
 	static volatile bool enabled;
@@ -62,7 +59,7 @@ private:
 volatile bool AlarmManager::enabled = false;
 
 AlarmManager::AlarmManager()
-	: id(NULL), sem(1)
+	: id(nullptr), sem(1)
 {
 	if (SDL_Init(SDL_INIT_TIMER) < 0) {
 		throw FatalError(StringOp::Builder() <<
@@ -97,7 +94,7 @@ void AlarmManager::registerAlarm(Alarm& alarm)
 void AlarmManager::unregisterAlarm(Alarm& alarm)
 {
 	ScopedLock lock(sem);
-	Alarms::iterator it = find(alarms.begin(), alarms.end(), &alarm);
+	auto it = find(alarms.begin(), alarms.end(), &alarm);
 	assert(it != alarms.end());
 	alarms.erase(it);
 }
@@ -116,7 +113,7 @@ void AlarmManager::start(Alarm& alarm, unsigned period)
 
 	if (id) {
 		// there already is a timer
-		long long diff = time - alarm.time;
+		int64_t diff = time - alarm.time;
 		if (diff <= 0) {
 			// but we already have an earlier timer, do nothing
 		} else {
@@ -150,7 +147,7 @@ unsigned AlarmManager::timerCallback(unsigned /*interval*/, void* param)
 {
 	// note: runs in a different thread!
 	if (!enabled) return 0;
-	AlarmManager* manager = static_cast<AlarmManager*>(param);
+	auto manager = static_cast<AlarmManager*>(param);
 	return manager->timerCallback2();
 }
 
@@ -159,28 +156,26 @@ unsigned AlarmManager::timerCallback2()
 	// note: runs in a different thread!
 	ScopedLock lock(sem);
 
-	long long now = Timer::getTime();
-	long long earliest = std::numeric_limits<long long>::max();
-	for (Alarms::const_iterator it = alarms.begin();
-	     it != alarms.end(); ++it) {
-		Alarm& alarm = **it;
-		if (alarm.active) {
+	int64_t now = Timer::getTime();
+	int64_t earliest = std::numeric_limits<int64_t>::max();
+	for (auto& a : alarms) {
+		if (a->active) {
 			// timer active
-			// note: don't compare time directly (alarm.time < now),
+			// note: don't compare time directly (a->time < now),
 			//       because there is a small chance time will wrap
-			long long left = alarm.time - now;
+			int64_t left = a->time - now;
 			if (left <= 0) {
 				// timer expired
-				if (alarm.alarm()) {
+				if (a->alarm()) {
 					// repeat
-					alarm.time += alarm.period;
-					left = alarm.time - now;
+					a->time += a->period;
+					left = a->time - now;
 					// 'left' can still be negative at this
 					// point, but that's ok .. convert()
 					// will return '1' in that case
 					earliest = std::min(earliest, left);
 				} else {
-					alarm.active = false;
+					a->active = false;
 				}
 			} else {
 				// timer active but not yet expired
@@ -188,16 +183,15 @@ unsigned AlarmManager::timerCallback2()
 			}
 		}
 	}
-	if (earliest != std::numeric_limits<long long>::max()) {
+	if (earliest != std::numeric_limits<int64_t>::max()) {
 		time = earliest + now;
-		assert(id != NULL);
+		assert(id);
 		return convert(int(earliest));
 	} else {
-		for (Alarms::const_iterator it = alarms.begin();
-		     it != alarms.end(); ++it) {
-			assert((*it)->active == false);
+		for (auto& a : alarms) {
+			assert(a->active == false); (void)a;
 		}
-		id = NULL;
+		id = nullptr;
 		return 0; // don't repeat
 	}
 }
