@@ -1,18 +1,6 @@
 #include "StringMap.hh"
-
-// Hash function for strings
-//  Fowler / Noll / Vo (FNV-1a) Hash
-//  http://www.isthe.com/chongo/tech/comp/fnv/
-static inline unsigned hashString(string_ref str)
-{
-	unsigned hash = 2166136261u;
-	for (unsigned i = 0; i < str.size(); ++i) {
-		hash ^= str[i];
-		hash *= 16777619;
-	}
-	return hash;
-}
-
+#include "StringOp.hh"
+#include "xxhash.hh"
 
 StringMapImpl::StringMapImpl(unsigned itemSize_, unsigned initSize)
 	: itemSize(itemSize_)
@@ -49,100 +37,6 @@ void StringMapImpl::init(unsigned initSize)
 	theTable[numBuckets] = reinterpret_cast<StringMapEntryBase*>(2);
 }
 
-unsigned StringMapImpl::lookupBucketFor(string_ref name)
-{
-	if (numBuckets == 0) { // Hash table unallocated so far?
-		init(16);
-	}
-	unsigned fullHashValue = hashString(name);
-	unsigned bucketNo = fullHashValue & (numBuckets - 1);
-	unsigned* hashTable = getHashTable();
-
-	unsigned probeAmt = 1;
-	int firstTombstone = -1;
-	while (true) {
-		StringMapEntryBase* bucketItem = theTable[bucketNo];
-		if (!bucketItem) {
-			// Empty bucket, this means the key isn't in the table
-			// yet. If we found a tombstone earlier, then reuse
-			// that instead of using this empty bucket.
-			if (firstTombstone != -1) {
-				hashTable[firstTombstone] = fullHashValue;
-				return firstTombstone;
-			}
-			hashTable[bucketNo] = fullHashValue;
-			return bucketNo;
-		} else if (bucketItem == getTombstoneVal()) {
-			// Skip tombstones, but remember the first one we see.
-			if (firstTombstone == -1) firstTombstone = bucketNo;
-		} else if (hashTable[bucketNo] == fullHashValue) {
-			// If the full hash value matches, check deeply for a
-			// match.  The common case here is that we are only
-			// looking at the buckets (for item info being non-nullptr
-			// and for the full hash value) not at the items.  This
-			// is important for cache locality.
-			auto itemStr = reinterpret_cast<char*>(bucketItem) + itemSize;
-			if (name == string_ref(itemStr, bucketItem->getKeyLength())) {
-				return bucketNo;
-			}
-		}
-
-		// Use quadratic probing, it has fewer clumping artifacts than linear
-		// probing and has good cache behavior in the common case.
-		bucketNo = (bucketNo + probeAmt) & (numBuckets - 1);
-		++probeAmt;
-	}
-}
-
-int StringMapImpl::findKey(string_ref key) const
-{
-	if (numBuckets == 0) return -1;
-
-	unsigned fullHashValue = hashString(key);
-	unsigned bucketNo = fullHashValue & (numBuckets - 1);
-	unsigned* hashTable = getHashTable();
-
-	unsigned probeAmt = 1;
-	while (true) {
-		StringMapEntryBase* bucketItem = theTable[bucketNo];
-		if (!bucketItem) {
-			// Empty bucket, key isn't in the table yet.
-			return -1;
-		} else if (bucketItem == getTombstoneVal()) {
-			// Ignore tombstones.
-		} else if (hashTable[bucketNo] == fullHashValue) {
-			// Hash matches, compare full string.
-			auto itemStr = reinterpret_cast<char*>(bucketItem) + itemSize;
-			if (key == string_ref(itemStr, bucketItem->getKeyLength())) {
-				return bucketNo;
-			}
-		}
-		// Quadratic probing.
-		bucketNo = (bucketNo + probeAmt) & (numBuckets - 1);
-		++probeAmt;
-	}
-}
-
-void StringMapImpl::removeKey(StringMapEntryBase* v)
-{
-	auto vStr = reinterpret_cast<char*>(v) + itemSize;
-	StringMapEntryBase* v2 = removeKey(string_ref(vStr, v->getKeyLength()));
-	assert(v == v2 && "Didn't find key?"); (void)v2;
-}
-
-StringMapEntryBase* StringMapImpl::removeKey(string_ref key)
-{
-	int bucket = findKey(key);
-	if (bucket == -1) return nullptr;
-
-	StringMapEntryBase* result = theTable[bucket];
-	theTable[bucket] = getTombstoneVal();
-	--numItems;
-	++numTombstones;
-	assert(numItems + numTombstones <= numBuckets);
-	return result;
-}
-
 void StringMapImpl::rehashTable()
 {
 	// If the hash table is now more than 3/4 full, or if fewer than 1/8 of
@@ -196,3 +90,130 @@ void StringMapImpl::rehashTable()
 	numBuckets = newSize;
 	numTombstones = 0;
 }
+
+
+template<bool CASE_SENSITIVE>
+static inline uint32_t hash(string_ref key)
+{
+	return (CASE_SENSITIVE) ? xxhash(key) : xxhash_case(key);
+}
+
+template<bool CASE_SENSITIVE>
+static inline bool equal(string_ref x, string_ref y)
+{
+	if (CASE_SENSITIVE) {
+		return x == y;
+	} else {
+		StringOp::casecmp cmp;
+		return cmp(x, y);
+	}
+}
+
+template<bool CASE_SENSITIVE>
+StringMapImpl2<CASE_SENSITIVE>::StringMapImpl2(unsigned itemSize, unsigned initSize)
+	: StringMapImpl(itemSize, initSize)
+{
+}
+
+template<bool CASE_SENSITIVE>
+unsigned StringMapImpl2<CASE_SENSITIVE>::lookupBucketFor(string_ref name)
+{
+	if (numBuckets == 0) { // Hash table unallocated so far?
+		init(16);
+	}
+	unsigned fullHashValue = hash<CASE_SENSITIVE>(name);
+	unsigned bucketNo = fullHashValue & (numBuckets - 1);
+	unsigned* hashTable = getHashTable();
+
+	unsigned probeAmt = 1;
+	int firstTombstone = -1;
+	while (true) {
+		StringMapEntryBase* bucketItem = theTable[bucketNo];
+		if (!bucketItem) {
+			// Empty bucket, this means the key isn't in the table
+			// yet. If we found a tombstone earlier, then reuse
+			// that instead of using this empty bucket.
+			if (firstTombstone != -1) {
+				hashTable[firstTombstone] = fullHashValue;
+				return firstTombstone;
+			}
+			hashTable[bucketNo] = fullHashValue;
+			return bucketNo;
+		} else if (bucketItem == getTombstoneVal()) {
+			// Skip tombstones, but remember the first one we see.
+			if (firstTombstone == -1) firstTombstone = bucketNo;
+		} else if (hashTable[bucketNo] == fullHashValue) {
+			// If the full hash value matches, check deeply for a
+			// match.  The common case here is that we are only
+			// looking at the buckets (for item info being non-nullptr
+			// and for the full hash value) not at the items.  This
+			// is important for cache locality.
+			auto itemStr = reinterpret_cast<char*>(bucketItem) + itemSize;
+			if (equal<CASE_SENSITIVE>(
+			      name, string_ref(itemStr, bucketItem->getKeyLength()))) {
+				return bucketNo;
+			}
+		}
+
+		// Use quadratic probing, it has fewer clumping artifacts than linear
+		// probing and has good cache behavior in the common case.
+		bucketNo = (bucketNo + probeAmt) & (numBuckets - 1);
+		++probeAmt;
+	}
+}
+
+template<bool CASE_SENSITIVE>
+int StringMapImpl2<CASE_SENSITIVE>::findKey(string_ref key) const
+{
+	if (numBuckets == 0) return -1;
+
+	unsigned fullHashValue = hash<CASE_SENSITIVE>(key);
+	unsigned bucketNo = fullHashValue & (numBuckets - 1);
+	unsigned* hashTable = getHashTable();
+
+	unsigned probeAmt = 1;
+	while (true) {
+		StringMapEntryBase* bucketItem = theTable[bucketNo];
+		if (!bucketItem) {
+			// Empty bucket, key isn't in the table yet.
+			return -1;
+		} else if (bucketItem == getTombstoneVal()) {
+			// Ignore tombstones.
+		} else if (hashTable[bucketNo] == fullHashValue) {
+			// Hash matches, compare full string.
+			auto itemStr = reinterpret_cast<char*>(bucketItem) + itemSize;
+			if (equal<CASE_SENSITIVE>(
+			      key, string_ref(itemStr, bucketItem->getKeyLength()))) {
+				return bucketNo;
+			}
+		}
+		// Quadratic probing.
+		bucketNo = (bucketNo + probeAmt) & (numBuckets - 1);
+		++probeAmt;
+	}
+}
+
+template<bool CASE_SENSITIVE>
+void StringMapImpl2<CASE_SENSITIVE>::removeKey(StringMapEntryBase* v)
+{
+	auto vStr = reinterpret_cast<char*>(v) + itemSize;
+	StringMapEntryBase* v2 = removeKey(string_ref(vStr, v->getKeyLength()));
+	assert(v == v2 && "Didn't find key?"); (void)v2;
+}
+
+template<bool CASE_SENSITIVE>
+StringMapEntryBase* StringMapImpl2<CASE_SENSITIVE>::removeKey(string_ref key)
+{
+	int bucket = findKey(key);
+	if (bucket == -1) return nullptr;
+
+	StringMapEntryBase* result = theTable[bucket];
+	theTable[bucket] = getTombstoneVal();
+	--numItems;
+	++numTombstones;
+	assert(numItems + numTombstones <= numBuckets);
+	return result;
+}
+
+template class StringMapImpl2<true>;
+template class StringMapImpl2<false>;
