@@ -1,5 +1,3 @@
-// $Id: ADVram.cc 12527 2012-05-17 17:34:11Z m9710797 $
-
 #include "ADVram.hh"
 #include "VDP.hh"
 #include "VDPVRAM.hh"
@@ -11,8 +9,8 @@ namespace openmsx {
 
 ADVram::ADVram(const DeviceConfig& config)
 	: MSXDevice(config)
-	, vdp(NULL)
-	, vram(NULL)
+	, vdp(nullptr)
+	, vram(nullptr)
 	, hasEnable(config.getChildDataAsBool("hasEnable", true))
 {
 	reset(EmuTime::dummy());
