@@ -1,10 +1,9 @@
 #include "BitmapConverter.hh"
-#include "GLUtil.hh"
 #include "Math.hh"
 #include "likely.hh"
 #include "unreachable.hh"
 #include "build-info.hh"
-#include <type_traits>
+#include "components.hh"
 #include <cstdint>
 
 namespace openmsx {
