@@ -9,13 +9,12 @@ TODO:
 */
 
 #include "CharacterConverter.hh"
-#include "GLUtil.hh"
 #include "VDP.hh"
 #include "VDPVRAM.hh"
 #include "unreachable.hh"
 #include "build-info.hh"
+#include "components.hh"
 #include <cstdint>
-#include <type_traits>
 
 namespace openmsx {
 
@@ -24,6 +23,7 @@ CharacterConverter<Pixel>::CharacterConverter(
 	VDP& vdp_, const Pixel* palFg_, const Pixel* palBg_)
 	: vdp(vdp_), vram(vdp.getVRAM()), palFg(palFg_), palBg(palBg_)
 {
+	modeBase = 0; // not strictly needed, but avoids Coverity warning
 }
 
 template <class Pixel>
@@ -72,7 +72,7 @@ void CharacterConverter<Pixel>::renderText1(
 	unsigned nameStart = (line / 8) * 40;
 	unsigned nameEnd = nameStart + 40;
 	for (unsigned name = nameStart; name < nameEnd; ++name) {
-		unsigned charcode = vram.nameTable.readNP((name + 0xC00) | (-1 << 12));
+		unsigned charcode = vram.nameTable.readNP((name + 0xC00) | (~0u << 12));
 		unsigned pattern = patternArea[charcode * 8];
 		pixelPtr[0] = (pattern & 0x80) ? fg : bg;
 		pixelPtr[1] = (pattern & 0x40) ? fg : bg;
@@ -91,7 +91,7 @@ void CharacterConverter<Pixel>::renderText1Q(
 	Pixel fg = palFg[vdp.getForegroundColor()];
 	Pixel bg = palFg[vdp.getBackgroundColor()];
 
-	unsigned patternBaseLine = (-1 << 13) | ((line + vdp.getVerticalScroll()) & 7);
+	unsigned patternBaseLine = (~0u << 13) | ((line + vdp.getVerticalScroll()) & 7);
 
 	// Note: Because line width is not a power of two, reading an entire line
 	//       from a VRAM pointer returned by readArea will not wrap the index
@@ -100,7 +100,7 @@ void CharacterConverter<Pixel>::renderText1Q(
 	unsigned nameEnd = nameStart + 40;
 	unsigned patternQuarter = (line & 0xC0) << 2;
 	for (unsigned name = nameStart; name < nameEnd; ++name) {
-		unsigned charcode = vram.nameTable.readNP((name + 0xC00) | (-1 << 12));
+		unsigned charcode = vram.nameTable.readNP((name + 0xC00) | (~0u << 12));
 		unsigned patternNr = patternQuarter | charcode;
 		unsigned pattern = vram.patternTable.readNP(
 			patternBaseLine | (patternNr * 8));
@@ -138,9 +138,9 @@ void CharacterConverter<Pixel>::renderText2(
 	unsigned nameStart  = (line / 8) * 80;
 	for (unsigned i = 0; i < (80 / 8); ++i) {
 		unsigned colorPattern = vram.colorTable.readNP(
-			(colorStart + i) | (-1 << 9));
+			(colorStart + i) | (~0u << 9));
 		const byte* nameArea = vram.nameTable.getReadArea(
-			(nameStart + 8 * i) | (-1 << 12), 8);
+			(nameStart + 8 * i) | (~0u << 12), 8);
 
 		Pixel fg0 = (colorPattern & 0x80) ? blinkFg : plainFg;
 		Pixel bg0 = (colorPattern & 0x80) ? blinkBg : plainBg;
@@ -275,7 +275,7 @@ void CharacterConverter<Pixel>::renderGraphic2(
 	unsigned partial = *pixelPtr;
 #endif
 	int quarter = ((line / 8) * 32) & ~0xFF;
-	int baseLine = (-1 << 13) | (quarter * 8) | (line & 7);
+	int baseLine = (~0u << 13) | (quarter * 8) | (line & 7);
 
 	// pattern area is contiguous, color area not
 	const byte* patternArea = vram.patternTable.getReadArea(quarter * 8, 8 * 256);
@@ -430,7 +430,7 @@ template <class Pixel>
 void CharacterConverter<Pixel>::renderMulti(
 	Pixel* __restrict pixelPtr, int line)
 {
-	int mask = (-1 << 11);
+	int mask = (~0u << 11);
 	renderMultiHelper(pixelPtr, line, mask, 0);
 }
 
@@ -438,7 +438,7 @@ template <class Pixel>
 void CharacterConverter<Pixel>::renderMultiQ(
 	Pixel* __restrict pixelPtr, int line)
 {
-	int mask = (-1 << 13);
+	int mask = (~0u << 13);
 	int patternQuarter = (line * 4) & ~0xFF;  // (line / 8) * 32
 	renderMultiHelper(pixelPtr, line, mask, patternQuarter);
 }
