@@ -14,6 +14,7 @@
 #include "aligned.hh"
 #include "xrange.hh"
 #include <algorithm>
+#include <random>
 #include <cassert>
 #include <cstdint>
 #ifdef __SSE2__
@@ -27,7 +28,7 @@ static const unsigned NOISE_BUF_SIZE = 2 * NOISE_SHIFT;
 SSE_ALIGNED(static signed char noiseBuf[NOISE_BUF_SIZE]);
 
 template <class Pixel>
-void FBPostProcessor<Pixel>::preCalcNoise(double factor)
+void FBPostProcessor<Pixel>::preCalcNoise(float factor)
 {
 	// We skip noise drawing if the factor is 0, so there is no point in
 	// initializing the random data in that case.
@@ -61,17 +62,14 @@ void FBPostProcessor<Pixel>::preCalcNoise(double factor)
 		scale[3] = 0.0;
 	}
 
-	for (unsigned i = 0; i < NOISE_BUF_SIZE; i += 8) {
-		double r1, r2;
-		Math::gaussian2(r1, r2);
-		noiseBuf[i + 0] = Math::clip<-128, 127>(r1, scale[0]);
-		noiseBuf[i + 1] = Math::clip<-128, 127>(r1, scale[1]);
-		noiseBuf[i + 2] = Math::clip<-128, 127>(r1, scale[2]);
-		noiseBuf[i + 3] = Math::clip<-128, 127>(r1, scale[3]);
-		noiseBuf[i + 4] = Math::clip<-128, 127>(r2, scale[0]);
-		noiseBuf[i + 5] = Math::clip<-128, 127>(r2, scale[1]);
-		noiseBuf[i + 6] = Math::clip<-128, 127>(r2, scale[2]);
-		noiseBuf[i + 7] = Math::clip<-128, 127>(r2, scale[3]);
+	std::minstd_rand generator; // fast (non-cryptographic) random numbers
+	std::normal_distribution<float> distribution(0.0f, 1.0f);
+	for (unsigned i = 0; i < NOISE_BUF_SIZE; i += 4) {
+		float r = distribution(generator);
+		noiseBuf[i + 0] = Math::clip<-128, 127>(r, scale[0]);
+		noiseBuf[i + 1] = Math::clip<-128, 127>(r, scale[1]);
+		noiseBuf[i + 2] = Math::clip<-128, 127>(r, scale[2]);
+		noiseBuf[i + 3] = Math::clip<-128, 127>(r, scale[3]);
 	}
 }
 
@@ -242,7 +240,7 @@ FBPostProcessor<Pixel>::FBPostProcessor(MSXMotherBoard& motherBoard,
 	, noiseShift(screen.getHeight())
 	, pixelOps(screen.getSDLFormat())
 {
-	scaleAlgorithm = static_cast<RenderSettings::ScaleAlgorithm>(-1); // not a valid scaler
+	scaleAlgorithm = RenderSettings::NO_SCALER;
 	scaleFactor = unsigned(-1);
 
 	FloatSetting& noiseSetting = renderSettings.getNoise();
