@@ -12,8 +12,8 @@ GLSnow::GLSnow(Display& display_, unsigned width_, unsigned height_)
 {
 	// Create noise texture.
 	byte buf[128 * 128];
-	for (int i = 0; i < 128 * 128; ++i) {
-		buf[i] = byte(rand());
+	for (auto& b : buf) {
+		b = byte(rand());
 	}
 	glGenTextures(1, &noiseTextureId);
 	glBindTexture(GL_TEXTURE_2D, noiseTextureId);
