@@ -4,7 +4,6 @@
 #include "EnumSetting.hh"
 #include "Display.hh"
 #include "Version.hh"
-#include "GLUtil.hh"
 #include "memory.hh"
 #include "unreachable.hh"
 
@@ -96,20 +95,21 @@ unique_ptr<LDRenderer> createLDRenderer(LaserdiscPlayer& ld, Display& display)
 unique_ptr<RendererSetting> createRendererSetting(
 	CommandController& commandController)
 {
-	EnumSetting<RendererID>::Map rendererMap;
-	rendererMap.push_back(std::make_pair("none", DUMMY)); // TODO: only register when in CliComm mode
-	rendererMap.push_back(std::make_pair("SDL", SDL));
+	EnumSetting<RendererID>::Map rendererMap = {
+		{ "none", DUMMY },// TODO: only register when in CliComm mode
+		{ "SDL", SDL } };
 #if COMPONENT_GL
 	// compiled with OpenGL-2.0, still need to test whether
 	// it's available at run time, but cannot be done here
-	rendererMap.push_back(std::make_pair("SDLGL-PP", SDLGL_PP));
+	rendererMap.emplace_back("SDLGL-PP", SDLGL_PP);
 	if (!Version::RELEASE) {
 		// disabled for the release:
 		//  these renderers don't offer anything more than the existing
 		//  renderers and sdlgl-fb32 still has endian problems on PPC
 		// TODO is this still true now that SDLGL is removed?
-		rendererMap.push_back(std::make_pair("SDLGL-FB16", SDLGL_FB16));
-		rendererMap.push_back(std::make_pair("SDLGL-FB32", SDLGL_FB32));
+		rendererMap.insert(rendererMap.end(), {
+			{"SDLGL-FB16", SDLGL_FB16},
+			{"SDLGL-FB32", SDLGL_FB32}});
 	}
 #endif
 	auto setting = make_unique<RendererSetting>(commandController,
