@@ -4,12 +4,14 @@
 #include "OSDConsoleRenderer.hh"
 #include "OSDGUILayer.hh"
 #include "InitException.hh"
+#include "RenderSettings.hh"
+#include "BooleanSetting.hh"
 #include "memory.hh"
 
 namespace openmsx {
 
 SDLGLVisibleSurface::SDLGLVisibleSurface(
-		unsigned width, unsigned height, bool fullscreen,
+		unsigned width, unsigned height,
 		RenderSettings& renderSettings,
 		EventDistributor& eventDistributor,
 		InputEventGenerator& inputEventGenerator,
@@ -21,7 +23,8 @@ SDLGLVisibleSurface::SDLGLVisibleSurface(
 	SDL_GL_SetAttribute(SDL_GL_DEPTH_SIZE, 0);
 	SDL_GL_SetAttribute(SDL_GL_STENCIL_SIZE, 0);
 	int flags = SDL_OPENGL | SDL_HWSURFACE | SDL_DOUBLEBUF |
-	            (fullscreen ? SDL_FULLSCREEN : 0);
+	            (renderSettings.getFullScreen().getBoolean() ?
+			SDL_FULLSCREEN : 0);
 	//flags |= SDL_RESIZABLE;
 	createSurface(width, height, flags);
 
