@@ -282,7 +282,7 @@ inline void SpriteChecker::checkSprites2(int minLine, int maxLine)
 					if (limitSprites) continue;
 				}
 				if (mag) spriteLine /= 2;
-				int colorIndex = (-1 << 10) | (sprite * 16 + spriteLine);
+				int colorIndex = (~0u << 10) | (sprite * 16 + spriteLine);
 				byte colorAttrib =
 					vram.spriteAttribTable.readPlanar(colorIndex);
 				// Sprites with CC=1 are only visible if preceded by
@@ -329,7 +329,7 @@ inline void SpriteChecker::checkSprites2(int minLine, int maxLine)
 					if (limitSprites) continue;
 				}
 				if (mag) spriteLine /= 2;
-				int colorIndex = (-1 << 10) | (sprite * 16 + spriteLine);
+				int colorIndex = (~0u << 10) | (sprite * 16 + spriteLine);
 				byte colorAttrib =
 					vram.spriteAttribTable.readNP(colorIndex);
 				// Sprites with CC=1 are only visible if preceded by
@@ -450,7 +450,7 @@ void SpriteChecker::serialize(Archive& ar, unsigned version)
 		// any influence on the MSX state. So the effect of not
 		// serializing these two is that no sprites will be shown in the
 		// first (partial) frame after loadstate.
-		for (int i = 0; i < 313; i++) spriteCount[i] = 0;
+		for (auto& c : spriteCount) c = 0;
 		// content of spriteBuffer[] doesn't matter if spriteCount[] is 0
 	}
 	ar.serialize("collisionX", collisionX);
