@@ -247,7 +247,7 @@ unsigned ZMBVEncoder::compareBlock(int vx, int vy, unsigned offset)
 
 template<class P>
 void ZMBVEncoder::addXorBlock(
-	const PixelOperations<P>& pixelOps, int vx, int vy, unsigned offset)
+	const PixelOperations<P>& pixelOps, int vx, int vy, unsigned offset, unsigned& workUsed)
 {
 	typedef typename Endian::Little<P>::type LE_P;
 
@@ -265,7 +265,7 @@ void ZMBVEncoder::addXorBlock(
 }
 
 template<class P>
-void ZMBVEncoder::addXorFrame(const SDL_PixelFormat& pixelFormat)
+void ZMBVEncoder::addXorFrame(const SDL_PixelFormat& pixelFormat, unsigned& workUsed)
 {
 	PixelOperations<P> pixelOps(pixelFormat);
 	auto* vectors = reinterpret_cast<int8_t*>(&work[workUsed]);
@@ -282,15 +282,13 @@ void ZMBVEncoder::addXorFrame(const SDL_PixelFormat& pixelFormat)
 		unsigned bestchange = compareBlock<P>(bestvx, bestvy, offset);
 		if (bestchange >= 4) {
 			int possibles = 64;
-			for (unsigned v = 0; v < VECTOR_TAB_SIZE; ++v) {
-				int vx = vectorTable[v].x;
-				int vy = vectorTable[v].y;
-				if (possibleBlock<P>(vx, vy, offset) < 4) {
-					unsigned testchange = compareBlock<P>(vx, vy, offset);
+			for (auto& v : vectorTable) {
+				if (possibleBlock<P>(v.x, v.y, offset) < 4) {
+					unsigned testchange = compareBlock<P>(v.x, v.y, offset);
 					if (testchange < bestchange) {
 						bestchange = testchange;
-						bestvx = vx;
-						bestvy = vy;
+						bestvx = v.x;
+						bestvy = v.y;
 						if (bestchange < 4) break;
 					}
 					--possibles;
@@ -302,13 +300,13 @@ void ZMBVEncoder::addXorFrame(const SDL_PixelFormat& pixelFormat)
 		vectors[b * 2 + 1] = (bestvy << 1);
 		if (bestchange) {
 			vectors[b * 2 + 0] |= 1;
-			addXorBlock<P>(pixelOps, bestvx, bestvy, offset);
+			addXorBlock<P>(pixelOps, bestvx, bestvy, offset, workUsed);
 		}
 	}
 }
 
 template<class P>
-void ZMBVEncoder::addFullFrame(const SDL_PixelFormat& pixelFormat)
+void ZMBVEncoder::addFullFrame(const SDL_PixelFormat& pixelFormat, unsigned& workUsed)
 {
 	typedef typename Endian::Little<P>::type LE_P;
 
@@ -364,7 +362,7 @@ void ZMBVEncoder::compressFrame(bool keyFrame, FrameSource* frame,
 	std::swap(newframe, oldframe); // replace oldframe with newframe
 
 	// Reset the work buffer
-	workUsed = 0;
+	unsigned workUsed = 0;
 	unsigned writeDone = 1;
 	uint8_t* writeBuf = output.data();
 
@@ -400,12 +398,12 @@ void ZMBVEncoder::compressFrame(bool keyFrame, FrameSource* frame,
 		switch (pixelSize) {
 #if HAVE_16BPP
 		case 2:
-			addFullFrame<uint16_t>(frame->getSDLPixelFormat());
+			addFullFrame<uint16_t>(frame->getSDLPixelFormat(), workUsed);
 			break;
 #endif
 #if HAVE_32BPP
 		case 4:
-			addFullFrame<uint32_t>(frame->getSDLPixelFormat());
+			addFullFrame<uint32_t>(frame->getSDLPixelFormat(), workUsed);
 			break;
 #endif
 		default:
@@ -416,12 +414,12 @@ void ZMBVEncoder::compressFrame(bool keyFrame, FrameSource* frame,
 		switch (pixelSize) {
 #if HAVE_16BPP
 		case 2:
-			addXorFrame<uint16_t>(frame->getSDLPixelFormat());
+			addXorFrame<uint16_t>(frame->getSDLPixelFormat(), workUsed);
 			break;
 #endif
 #if HAVE_32BPP
 		case 4:
-			addXorFrame<uint32_t>(frame->getSDLPixelFormat());
+			addXorFrame<uint32_t>(frame->getSDLPixelFormat(), workUsed);
 			break;
 #endif
 		default:
