@@ -1,5 +1,3 @@
-// $Id: GLScalerFactory.cc 11833 2010-12-21 11:07:23Z mthuurne $
-
 #include "GLScalerFactory.hh"
 #include "GLSimpleScaler.hh"
 #include "GLRGBScaler.hh"
@@ -10,40 +8,41 @@
 #include "GLHQLiteScaler.hh"
 #include "RenderSettings.hh"
 #include "EnumSetting.hh"
+#include "memory.hh"
 #include "unreachable.hh"
 
-using std::auto_ptr;
+using std::unique_ptr;
 
 namespace openmsx {
 namespace GLScalerFactory {
 
-auto_ptr<GLScaler> createScaler(RenderSettings& renderSettings)
+unique_ptr<GLScaler> createScaler(RenderSettings& renderSettings)
 {
-	switch (renderSettings.getScaleAlgorithm().getValue()) {
+	switch (renderSettings.getScaleAlgorithm().getEnum()) {
 	case RenderSettings::SCALER_SAI:
 		// disabled for now:
 		//   - it doesn't work (yet) on ATI cards
 		//   - it probably has some bugs because (on nvidia cards)
 		//     it does not give the same result as the SW SaI scaler,
 		//     although it's reasonably close
-		//return auto_ptr<GLScaler>(new GLSaIScaler());
+		//return make_unique<GLSaIScaler>();
 	case RenderSettings::SCALER_SIMPLE:
-		return auto_ptr<GLScaler>(new GLSimpleScaler(renderSettings));
+		return make_unique<GLSimpleScaler>(renderSettings);
 	case RenderSettings::SCALER_RGBTRIPLET:
-		return auto_ptr<GLScaler>(new GLRGBScaler(renderSettings));
+		return make_unique<GLRGBScaler>(renderSettings);
 	case RenderSettings::SCALER_SCALE:
-		return auto_ptr<GLScaler>(new GLScaleNxScaler());
+		return make_unique<GLScaleNxScaler>();
 	case RenderSettings::SCALER_TV:
-		return auto_ptr<GLScaler>(new GLTVScaler(renderSettings));
+		return make_unique<GLTVScaler>(renderSettings);
 	case RenderSettings::SCALER_HQ:
-		return auto_ptr<GLScaler>(new GLHQScaler());
+		return make_unique<GLHQScaler>();
 	case RenderSettings::SCALER_MLAA: // fallback
 	case RenderSettings::SCALER_HQLITE:
-		return auto_ptr<GLScaler>(new GLHQLiteScaler());
+		return make_unique<GLHQLiteScaler>();
 	default:
 		UNREACHABLE;
 	}
-	return auto_ptr<GLScaler>(); // avoid warning
+	return nullptr; // avoid warning
 }
 
 } // namespace GLScalerFactory
