@@ -1,5 +1,3 @@
-// $Id: V9990SDLRasterizer.cc 12699 2012-07-07 12:46:06Z m9710797 $
-
 #include "V9990SDLRasterizer.hh"
 #include "V9990.hh"
 #include "RawFrame.hh"
@@ -15,9 +13,11 @@
 #include "VisibleSurface.hh"
 #include "RenderSettings.hh"
 #include "MemoryOps.hh"
+#include "memory.hh"
 #include "build-info.hh"
 #include "components.hh"
 #include <algorithm>
+#include <cstdint>
 
 using std::min;
 using std::max;
@@ -27,19 +27,18 @@ namespace openmsx {
 template <class Pixel>
 V9990SDLRasterizer<Pixel>::V9990SDLRasterizer(
 		V9990& vdp_, Display& display, VisibleSurface& screen_,
-		std::auto_ptr<PostProcessor> postProcessor_
-		)
+		std::unique_ptr<PostProcessor> postProcessor_)
 	: vdp(vdp_), vram(vdp.getVRAM())
 	, screen(screen_)
-	, workFrame(new RawFrame(screen.getSDLFormat(), 1280, 240))
+	, workFrame(make_unique<RawFrame>(screen.getSDLFormat(), 1280, 240))
 	, renderSettings(display.getRenderSettings())
 	, displayMode(P1) // dummy value
 	, colorMode(PP)   //   avoid UMR
-	, postProcessor(postProcessor_)
-	, bitmapConverter(new V9990BitmapConverter<Pixel>(
-	                           vdp, palette64, palette256, palette32768))
-	, p1Converter(new V9990P1Converter<Pixel>(vdp, palette64))
-	, p2Converter(new V9990P2Converter<Pixel>(vdp, palette64))
+	, postProcessor(std::move(postProcessor_))
+	, bitmapConverter(make_unique<V9990BitmapConverter<Pixel>>(
+		vdp, palette64, palette256, palette32768))
+	, p1Converter(make_unique<V9990P1Converter<Pixel>>(vdp, palette64))
+	, p2Converter(make_unique<V9990P2Converter<Pixel>>(vdp, palette64))
 {
 	// Fill palettes
 	preCalcPalettes();
@@ -59,6 +58,12 @@ V9990SDLRasterizer<Pixel>::~V9990SDLRasterizer()
 	renderSettings.getContrast()   .detach(*this);
 }
 
+template <class Pixel>
+PostProcessor* V9990SDLRasterizer<Pixel>::getPostProcessor() const
+{
+	return postProcessor.get();
+}
+
 template <class Pixel>
 bool V9990SDLRasterizer<Pixel>::isActive()
 {
@@ -99,7 +104,7 @@ template <class Pixel>
 void V9990SDLRasterizer<Pixel>::frameEnd(EmuTime::param time)
 {
 	workFrame = postProcessor->rotateFrames(
-	    workFrame,
+	    std::move(workFrame),
 	    vdp.isInterlaced() ? (vdp.getEvenOdd() ? RawFrame::FIELD_EVEN
 	                                           : RawFrame::FIELD_ODD)
 	                       : RawFrame::FIELD_NONINTERLACED,
@@ -148,7 +153,7 @@ void V9990SDLRasterizer<Pixel>::drawBorder(
 	if (startX >= endX) return;
 
 	unsigned lineWidth = vdp.getLineWidth();
-	MemoryOps::MemSet<Pixel, MemoryOps::NO_STREAMING> memset;
+	MemoryOps::MemSet<Pixel> memset;
 	for (int y = startY; y < endY; ++y) {
 		memset(workFrame->getLinePtrDirect<Pixel>(y) + startX,
 		       endX - startX, bgColor);
@@ -192,7 +197,7 @@ void V9990SDLRasterizer<Pixel>::drawDisplay(
 
 	if ((toX > fromX) && (toY > fromY)) {
 		bool drawSprites = vdp.spritesEnabled() &&
-			!renderSettings.getDisableSprites().getValue();
+			!renderSettings.getDisableSprites().getBoolean();
 
 		displayX = V9990::UCtoX(displayX, displayMode);
 		int displayWidth  = toX - fromX;
@@ -374,10 +379,10 @@ void V9990SDLRasterizer<Pixel>::update(const Setting& setting)
 
 // Force template instantiation.
 #if HAVE_16BPP
-template class V9990SDLRasterizer<word>;
+template class V9990SDLRasterizer<uint16_t>;
 #endif
 #if HAVE_32BPP || COMPONENT_GL
-template class V9990SDLRasterizer<unsigned>;
+template class V9990SDLRasterizer<uint32_t>;
 #endif
 
 } // namespace openmsx
